searchData={"items":[{"type":"behaviour","title":"ExTypesense","doc":"Public API functions to interact with Typesense.\n\nIf you want to implement field types for your Ecto schema,\nyou may need to encode the schema and add the callback [`get_field_types/0`](`c:ExTypesense.get_field_types/0`):\n\n> #### Schema and field types for Ecto {: .info}\n>\n> The code below is when you're using it with Ecto schema.\n> Skip this if you just want plain old maps\n\n```elixir\ndefmodule App.Person do\n  use Ecto.Schema\n  @behaviour ExTypesense\n\n  defimpl Jason.Encoder, for: __MODULE__ do\n    def encode(value, opts) do\n      value\n      |> Map.take([:id, :persons_id, :name, :age])\n      |> Enum.map(fn {key, val} ->\n        cond do\n          key === :id -> {key, to_string(Map.get(value, :id))}\n          key === :persons_id -> {key, Map.get(value, :id)}\n          true -> {key, val}\n        end\n      end)\n      |> Enum.into(%{})\n      |> Jason.Encode.map(opts)\n    end\n  end\n\n  schema \"persons\" do\n    field :name, :string\n    field :age, :integer\n    field :persons_id, :integer, virtual: true\n  end\n\n  @impl ExTypesense\n  def get_field_types do\n    name = __MODULE__.__schema__(:source)\n    primary_field = name <> \"_id\"\n\n    %{\n      name: name,\n      default_sorting_field: primary_field,\n      fields:\n        [\n          %{name: primary_field, type: \"int32\"},\n          %{name: \"name\", type: \"string\"},\n          %{name: \"age\", type: \"integer\"}\n        ]\n    }\n  end\nend\n```","ref":"ExTypesense.html"},{"type":"function","title":"ExTypesense.api_stats/0","doc":"See  ExTypesense.Cluster.api_stats/0 .","ref":"ExTypesense.html#api_stats/0"},{"type":"function","title":"ExTypesense.api_stats/1","doc":"See  ExTypesense.Cluster.api_stats/1 .","ref":"ExTypesense.html#api_stats/1"},{"type":"function","title":"ExTypesense.clear_cache/0","doc":"See  ExTypesense.Cluster.clear_cache/0 .","ref":"ExTypesense.html#clear_cache/0"},{"type":"function","title":"ExTypesense.clear_cache/1","doc":"See  ExTypesense.Cluster.clear_cache/1 .","ref":"ExTypesense.html#clear_cache/1"},{"type":"function","title":"ExTypesense.clone_collection/2","doc":"See  ExTypesense.Collection.clone_collection/2 .","ref":"ExTypesense.html#clone_collection/2"},{"type":"function","title":"ExTypesense.clone_collection/3","doc":"See  ExTypesense.Collection.clone_collection/3 .","ref":"ExTypesense.html#clone_collection/3"},{"type":"function","title":"ExTypesense.cluster_metrics/0","doc":"See  ExTypesense.Cluster.cluster_metrics/0 .","ref":"ExTypesense.html#cluster_metrics/0"},{"type":"function","title":"ExTypesense.cluster_metrics/1","doc":"See  ExTypesense.Cluster.cluster_metrics/1 .","ref":"ExTypesense.html#cluster_metrics/1"},{"type":"function","title":"ExTypesense.compact_db/0","doc":"See  ExTypesense.Cluster.compact_db/0 .","ref":"ExTypesense.html#compact_db/0"},{"type":"function","title":"ExTypesense.compact_db/1","doc":"See  ExTypesense.Cluster.compact_db/1 .","ref":"ExTypesense.html#compact_db/1"},{"type":"function","title":"ExTypesense.create_analytics_event/1","doc":"See  ExTypesense.Analytics.create_analytics_event/1 .","ref":"ExTypesense.html#create_analytics_event/1"},{"type":"function","title":"ExTypesense.create_analytics_event/2","doc":"See  ExTypesense.Analytics.create_analytics_event/2 .","ref":"ExTypesense.html#create_analytics_event/2"},{"type":"function","title":"ExTypesense.create_analytics_rule/1","doc":"See  ExTypesense.Analytics.create_analytics_rule/1 .","ref":"ExTypesense.html#create_analytics_rule/1"},{"type":"function","title":"ExTypesense.create_analytics_rule/2","doc":"See  ExTypesense.Analytics.create_analytics_rule/2 .","ref":"ExTypesense.html#create_analytics_rule/2"},{"type":"function","title":"ExTypesense.create_collection/1","doc":"See  ExTypesense.Collection.create_collection/1 .","ref":"ExTypesense.html#create_collection/1"},{"type":"function","title":"ExTypesense.create_collection/2","doc":"See  ExTypesense.Collection.create_collection/2 .","ref":"ExTypesense.html#create_collection/2"},{"type":"function","title":"ExTypesense.create_collection_with_alias/1","doc":"See  ExTypesense.Collection.create_collection_with_alias/1 .","ref":"ExTypesense.html#create_collection_with_alias/1"},{"type":"function","title":"ExTypesense.create_collection_with_alias/2","doc":"See  ExTypesense.Collection.create_collection_with_alias/2 .","ref":"ExTypesense.html#create_collection_with_alias/2"},{"type":"function","title":"ExTypesense.create_key/1","doc":"See  ExTypesense.Key.create_key/1 .","ref":"ExTypesense.html#create_key/1"},{"type":"function","title":"ExTypesense.create_key/2","doc":"See  ExTypesense.Key.create_key/2 .","ref":"ExTypesense.html#create_key/2"},{"type":"function","title":"ExTypesense.create_model/1","doc":"See  ExTypesense.Conversation.create_model/1 .","ref":"ExTypesense.html#create_model/1"},{"type":"function","title":"ExTypesense.create_model/2","doc":"See  ExTypesense.Conversation.create_model/2 .","ref":"ExTypesense.html#create_model/2"},{"type":"function","title":"ExTypesense.create_snapshot/1","doc":"See  ExTypesense.Cluster.create_snapshot/1 .","ref":"ExTypesense.html#create_snapshot/1"},{"type":"function","title":"ExTypesense.debug/0","doc":"See  ExTypesense.Debug.debug/0 .","ref":"ExTypesense.html#debug/0"},{"type":"function","title":"ExTypesense.debug/1","doc":"See  ExTypesense.Debug.debug/1 .","ref":"ExTypesense.html#debug/1"},{"type":"function","title":"ExTypesense.delete_all_documents/1","doc":"See  ExTypesense.Document.delete_all_documents/1 .","ref":"ExTypesense.html#delete_all_documents/1"},{"type":"function","title":"ExTypesense.delete_all_documents/2","doc":"See  ExTypesense.Document.delete_all_documents/2 .","ref":"ExTypesense.html#delete_all_documents/2"},{"type":"function","title":"ExTypesense.delete_analytics_rule/1","doc":"See  ExTypesense.Analytics.delete_analytics_rule/1 .","ref":"ExTypesense.html#delete_analytics_rule/1"},{"type":"function","title":"ExTypesense.delete_analytics_rule/2","doc":"See  ExTypesense.Analytics.delete_analytics_rule/2 .","ref":"ExTypesense.html#delete_analytics_rule/2"},{"type":"function","title":"ExTypesense.delete_collection_alias/1","doc":"See  ExTypesense.Collection.delete_collection_alias/1 .","ref":"ExTypesense.html#delete_collection_alias/1"},{"type":"function","title":"ExTypesense.delete_collection_alias/2","doc":"See  ExTypesense.Collection.delete_collection_alias/2 .","ref":"ExTypesense.html#delete_collection_alias/2"},{"type":"function","title":"ExTypesense.delete_document/1","doc":"See  ExTypesense.Document.delete_document/1 .","ref":"ExTypesense.html#delete_document/1"},{"type":"function","title":"ExTypesense.delete_document/2","doc":"See  ExTypesense.Document.delete_document/2 .","ref":"ExTypesense.html#delete_document/2"},{"type":"function","title":"ExTypesense.delete_document/3","doc":"See  ExTypesense.Document.delete_document/3 .","ref":"ExTypesense.html#delete_document/3"},{"type":"function","title":"ExTypesense.delete_documents_by_query/2","doc":"See  ExTypesense.Document.delete_documents_by_query/2 .","ref":"ExTypesense.html#delete_documents_by_query/2"},{"type":"function","title":"ExTypesense.delete_key/1","doc":"See  ExTypesense.Key.delete_key/1 .","ref":"ExTypesense.html#delete_key/1"},{"type":"function","title":"ExTypesense.delete_key/2","doc":"See  ExTypesense.Key.delete_key/2 .","ref":"ExTypesense.html#delete_key/2"},{"type":"function","title":"ExTypesense.delete_model/1","doc":"See  ExTypesense.Conversation.delete_model/1 .","ref":"ExTypesense.html#delete_model/1"},{"type":"function","title":"ExTypesense.delete_model/2","doc":"See  ExTypesense.Conversation.delete_model/2 .","ref":"ExTypesense.html#delete_model/2"},{"type":"function","title":"ExTypesense.delete_override/2","doc":"See  ExTypesense.Curation.delete_override/2 .","ref":"ExTypesense.html#delete_override/2"},{"type":"function","title":"ExTypesense.delete_override/3","doc":"See  ExTypesense.Curation.delete_override/3 .","ref":"ExTypesense.html#delete_override/3"},{"type":"function","title":"ExTypesense.delete_preset/1","doc":"See  ExTypesense.Preset.delete_preset/1 .","ref":"ExTypesense.html#delete_preset/1"},{"type":"function","title":"ExTypesense.delete_preset/2","doc":"See  ExTypesense.Preset.delete_preset/2 .","ref":"ExTypesense.html#delete_preset/2"},{"type":"function","title":"ExTypesense.delete_stopword/1","doc":"See  ExTypesense.Stopwords.delete_stopword/1 .","ref":"ExTypesense.html#delete_stopword/1"},{"type":"function","title":"ExTypesense.delete_stopword/2","doc":"See  ExTypesense.Stopwords.delete_stopword/2 .","ref":"ExTypesense.html#delete_stopword/2"},{"type":"function","title":"ExTypesense.delete_synonym/2","doc":"See  ExTypesense.Synonym.delete_synonym/2 .","ref":"ExTypesense.html#delete_synonym/2"},{"type":"function","title":"ExTypesense.delete_synonym/3","doc":"See  ExTypesense.Synonym.delete_synonym/3 .","ref":"ExTypesense.html#delete_synonym/3"},{"type":"function","title":"ExTypesense.drop_collection/1","doc":"See  ExTypesense.Collection.drop_collection/1 .","ref":"ExTypesense.html#drop_collection/1"},{"type":"function","title":"ExTypesense.drop_collection/2","doc":"See  ExTypesense.Collection.drop_collection/2 .","ref":"ExTypesense.html#drop_collection/2"},{"type":"function","title":"ExTypesense.export_documents/1","doc":"See  ExTypesense.Document.export_documents/1 .","ref":"ExTypesense.html#export_documents/1"},{"type":"function","title":"ExTypesense.export_documents/2","doc":"See  ExTypesense.Document.export_documents/2 .","ref":"ExTypesense.html#export_documents/2"},{"type":"function","title":"ExTypesense.get_analytics_rule/1","doc":"See  ExTypesense.Analytics.get_analytics_rule/1 .","ref":"ExTypesense.html#get_analytics_rule/1"},{"type":"function","title":"ExTypesense.get_analytics_rule/2","doc":"See  ExTypesense.Analytics.get_analytics_rule/2 .","ref":"ExTypesense.html#get_analytics_rule/2"},{"type":"function","title":"ExTypesense.get_collection/1","doc":"See  ExTypesense.Collection.get_collection/1 .","ref":"ExTypesense.html#get_collection/1"},{"type":"function","title":"ExTypesense.get_collection/2","doc":"See  ExTypesense.Collection.get_collection/2 .","ref":"ExTypesense.html#get_collection/2"},{"type":"function","title":"ExTypesense.get_collection_alias/1","doc":"See  ExTypesense.Collection.get_collection_alias/1 .","ref":"ExTypesense.html#get_collection_alias/1"},{"type":"function","title":"ExTypesense.get_collection_alias/2","doc":"See  ExTypesense.Collection.get_collection_alias/2 .","ref":"ExTypesense.html#get_collection_alias/2"},{"type":"function","title":"ExTypesense.get_document/2","doc":"See  ExTypesense.Document.get_document/2 .","ref":"ExTypesense.html#get_document/2"},{"type":"function","title":"ExTypesense.get_document/3","doc":"See  ExTypesense.Document.get_document/3 .","ref":"ExTypesense.html#get_document/3"},{"type":"callback","title":"ExTypesense.get_field_types/0","doc":"A callback function for creating the schema fields in Typesense.\n\n> #### Where to add {: .info}\n>\n> This function should be added in the Ecto Schema that you\n> will be use to import to Typesense.\n\n```elixir\ndefmodule MyApp.Accounts.User do\n  use Ecto.Schema\n  @behaviour ExTypesense\n\n  #... Lots of user-related code + Ecto schema\n\n  @impl ExTypesense\n  def get_field_types do\n    name = __MODULE__.__schema__(:source)\n    primary_field = name <> \"_id\"\n\n    %{\n      name: name,\n      default_sorting_field: primary_field,\n      fields:\n        [\n          %{name: primary_field, type: \"int32\"},\n          %{name: \"name\", type: \"string\"},\n          %{name: \"age\", type: \"integer\"}\n        ]\n    }\n  end\n```","ref":"ExTypesense.html#c:get_field_types/0"},{"type":"function","title":"ExTypesense.get_key/1","doc":"See  ExTypesense.Key.get_key/1 .","ref":"ExTypesense.html#get_key/1"},{"type":"function","title":"ExTypesense.get_key/2","doc":"See  ExTypesense.Key.get_key/2 .","ref":"ExTypesense.html#get_key/2"},{"type":"function","title":"ExTypesense.get_model/1","doc":"See  ExTypesense.Conversation.get_model/1 .","ref":"ExTypesense.html#get_model/1"},{"type":"function","title":"ExTypesense.get_model/2","doc":"See  ExTypesense.Conversation.get_model/2 .","ref":"ExTypesense.html#get_model/2"},{"type":"function","title":"ExTypesense.get_override/2","doc":"See  ExTypesense.Curation.get_override/2 .","ref":"ExTypesense.html#get_override/2"},{"type":"function","title":"ExTypesense.get_override/3","doc":"See  ExTypesense.Curation.get_override/3 .","ref":"ExTypesense.html#get_override/3"},{"type":"function","title":"ExTypesense.get_preset/1","doc":"See  ExTypesense.Preset.get_preset/1 .","ref":"ExTypesense.html#get_preset/1"},{"type":"function","title":"ExTypesense.get_preset/2","doc":"See  ExTypesense.Preset.get_preset/2 .","ref":"ExTypesense.html#get_preset/2"},{"type":"function","title":"ExTypesense.get_schema_changes/0","doc":"See  ExTypesense.Cluster.get_schema_changes/0 .","ref":"ExTypesense.html#get_schema_changes/0"},{"type":"function","title":"ExTypesense.get_schema_changes/1","doc":"See  ExTypesense.Cluster.get_schema_changes/1 .","ref":"ExTypesense.html#get_schema_changes/1"},{"type":"function","title":"ExTypesense.get_stemming_dictionary/1","doc":"See  ExTypesense.Stemming.get_stemming_dictionary/1 .","ref":"ExTypesense.html#get_stemming_dictionary/1"},{"type":"function","title":"ExTypesense.get_stemming_dictionary/2","doc":"See  ExTypesense.Stemming.get_stemming_dictionary/2 .","ref":"ExTypesense.html#get_stemming_dictionary/2"},{"type":"function","title":"ExTypesense.get_stopword/1","doc":"See  ExTypesense.Stopwords.get_stopword/1 .","ref":"ExTypesense.html#get_stopword/1"},{"type":"function","title":"ExTypesense.get_stopword/2","doc":"See  ExTypesense.Stopwords.get_stopword/2 .","ref":"ExTypesense.html#get_stopword/2"},{"type":"function","title":"ExTypesense.get_synonym/2","doc":"See  ExTypesense.Synonym.get_synonym/2 .","ref":"ExTypesense.html#get_synonym/2"},{"type":"function","title":"ExTypesense.get_synonym/3","doc":"See  ExTypesense.Synonym.get_synonym/3 .","ref":"ExTypesense.html#get_synonym/3"},{"type":"function","title":"ExTypesense.health/0","doc":"See  ExTypesense.Cluster.health/0 .","ref":"ExTypesense.html#health/0"},{"type":"function","title":"ExTypesense.health/1","doc":"See  ExTypesense.Cluster.health/1 .","ref":"ExTypesense.html#health/1"},{"type":"function","title":"ExTypesense.import_documents/2","doc":"See  ExTypesense.Document.import_documents/2 .","ref":"ExTypesense.html#import_documents/2"},{"type":"function","title":"ExTypesense.import_documents/3","doc":"See  ExTypesense.Document.import_documents/3 .","ref":"ExTypesense.html#import_documents/3"},{"type":"function","title":"ExTypesense.import_stemming_dictionary/2","doc":"See  ExTypesense.Stemming.import_stemming_dictionary/2 .","ref":"ExTypesense.html#import_stemming_dictionary/2"},{"type":"function","title":"ExTypesense.index_document/1","doc":"See  ExTypesense.Document.index_document/1 .","ref":"ExTypesense.html#index_document/1"},{"type":"function","title":"ExTypesense.index_document/2","doc":"See  ExTypesense.Document.index_document/2 .","ref":"ExTypesense.html#index_document/2"},{"type":"function","title":"ExTypesense.index_document/3","doc":"See  ExTypesense.Document.index_document/3 .","ref":"ExTypesense.html#index_document/3"},{"type":"function","title":"ExTypesense.list_analytics_rules/0","doc":"See  ExTypesense.Analytics.list_analytics_rules/0 .","ref":"ExTypesense.html#list_analytics_rules/0"},{"type":"function","title":"ExTypesense.list_analytics_rules/1","doc":"See  ExTypesense.Analytics.list_analytics_rules/1 .","ref":"ExTypesense.html#list_analytics_rules/1"},{"type":"function","title":"ExTypesense.list_collection_aliases/0","doc":"See  ExTypesense.Collection.list_collection_aliases/0 .","ref":"ExTypesense.html#list_collection_aliases/0"},{"type":"function","title":"ExTypesense.list_collection_aliases/1","doc":"See  ExTypesense.Collection.list_collection_aliases/1 .","ref":"ExTypesense.html#list_collection_aliases/1"},{"type":"function","title":"ExTypesense.list_collections/0","doc":"See  ExTypesense.Collection.list_collections/0 .","ref":"ExTypesense.html#list_collections/0"},{"type":"function","title":"ExTypesense.list_collections/1","doc":"See  ExTypesense.Collection.list_collections/1 .","ref":"ExTypesense.html#list_collections/1"},{"type":"function","title":"ExTypesense.list_keys/0","doc":"See  ExTypesense.Key.list_keys/0 .","ref":"ExTypesense.html#list_keys/0"},{"type":"function","title":"ExTypesense.list_keys/1","doc":"See  ExTypesense.Key.list_keys/1 .","ref":"ExTypesense.html#list_keys/1"},{"type":"function","title":"ExTypesense.list_models/0","doc":"See  ExTypesense.Conversation.list_models/0 .","ref":"ExTypesense.html#list_models/0"},{"type":"function","title":"ExTypesense.list_models/1","doc":"See  ExTypesense.Conversation.list_models/1 .","ref":"ExTypesense.html#list_models/1"},{"type":"function","title":"ExTypesense.list_overrides/1","doc":"See  ExTypesense.Curation.list_overrides/1 .","ref":"ExTypesense.html#list_overrides/1"},{"type":"function","title":"ExTypesense.list_overrides/2","doc":"See  ExTypesense.Curation.list_overrides/2 .","ref":"ExTypesense.html#list_overrides/2"},{"type":"function","title":"ExTypesense.list_presets/0","doc":"See  ExTypesense.Preset.list_presets/0 .","ref":"ExTypesense.html#list_presets/0"},{"type":"function","title":"ExTypesense.list_presets/1","doc":"See  ExTypesense.Preset.list_presets/1 .","ref":"ExTypesense.html#list_presets/1"},{"type":"function","title":"ExTypesense.list_stemming_dictionaries/0","doc":"See  ExTypesense.Stemming.list_stemming_dictionaries/0 .","ref":"ExTypesense.html#list_stemming_dictionaries/0"},{"type":"function","title":"ExTypesense.list_stemming_dictionaries/1","doc":"See  ExTypesense.Stemming.list_stemming_dictionaries/1 .","ref":"ExTypesense.html#list_stemming_dictionaries/1"},{"type":"function","title":"ExTypesense.list_stopwords/0","doc":"See  ExTypesense.Stopwords.list_stopwords/0 .","ref":"ExTypesense.html#list_stopwords/0"},{"type":"function","title":"ExTypesense.list_stopwords/1","doc":"See  ExTypesense.Stopwords.list_stopwords/1 .","ref":"ExTypesense.html#list_stopwords/1"},{"type":"function","title":"ExTypesense.list_synonyms/1","doc":"See  ExTypesense.Synonym.list_synonyms/1 .","ref":"ExTypesense.html#list_synonyms/1"},{"type":"function","title":"ExTypesense.list_synonyms/2","doc":"See  ExTypesense.Synonym.list_synonyms/2 .","ref":"ExTypesense.html#list_synonyms/2"},{"type":"function","title":"ExTypesense.multi_search/1","doc":"See  ExTypesense.Search.multi_search/1 .","ref":"ExTypesense.html#multi_search/1"},{"type":"function","title":"ExTypesense.multi_search/2","doc":"See  ExTypesense.Search.multi_search/2 .","ref":"ExTypesense.html#multi_search/2"},{"type":"function","title":"ExTypesense.multi_search_ecto/1","doc":"See  ExTypesense.Search.multi_search_ecto/1 .","ref":"ExTypesense.html#multi_search_ecto/1"},{"type":"function","title":"ExTypesense.multi_search_ecto/2","doc":"See  ExTypesense.Search.multi_search_ecto/2 .","ref":"ExTypesense.html#multi_search_ecto/2"},{"type":"function","title":"ExTypesense.search/2","doc":"See  ExTypesense.Search.search/2 .","ref":"ExTypesense.html#search/2"},{"type":"function","title":"ExTypesense.search_ecto/2","doc":"See  ExTypesense.Search.search_ecto/2 .","ref":"ExTypesense.html#search_ecto/2"},{"type":"function","title":"ExTypesense.toggle_slow_request_log/1","doc":"See  ExTypesense.Cluster.toggle_slow_request_log/1 .","ref":"ExTypesense.html#toggle_slow_request_log/1"},{"type":"function","title":"ExTypesense.toggle_slow_request_log/2","doc":"See  ExTypesense.Cluster.toggle_slow_request_log/2 .","ref":"ExTypesense.html#toggle_slow_request_log/2"},{"type":"function","title":"ExTypesense.update_collection_fields/2","doc":"See  ExTypesense.Collection.update_collection_fields/2 .","ref":"ExTypesense.html#update_collection_fields/2"},{"type":"function","title":"ExTypesense.update_collection_fields/3","doc":"See  ExTypesense.Collection.update_collection_fields/3 .","ref":"ExTypesense.html#update_collection_fields/3"},{"type":"function","title":"ExTypesense.update_document/1","doc":"See  ExTypesense.Document.update_document/1 .","ref":"ExTypesense.html#update_document/1"},{"type":"function","title":"ExTypesense.update_document/2","doc":"See  ExTypesense.Document.update_document/2 .","ref":"ExTypesense.html#update_document/2"},{"type":"function","title":"ExTypesense.update_documents_by_query/3","doc":"See  ExTypesense.Document.update_documents_by_query/3 .","ref":"ExTypesense.html#update_documents_by_query/3"},{"type":"function","title":"ExTypesense.update_model/2","doc":"See  ExTypesense.Conversation.update_model/2 .","ref":"ExTypesense.html#update_model/2"},{"type":"function","title":"ExTypesense.update_model/3","doc":"See  ExTypesense.Conversation.update_model/3 .","ref":"ExTypesense.html#update_model/3"},{"type":"function","title":"ExTypesense.upsert_analytics_rule/2","doc":"See  ExTypesense.Analytics.upsert_analytics_rule/2 .","ref":"ExTypesense.html#upsert_analytics_rule/2"},{"type":"function","title":"ExTypesense.upsert_analytics_rule/3","doc":"See  ExTypesense.Analytics.upsert_analytics_rule/3 .","ref":"ExTypesense.html#upsert_analytics_rule/3"},{"type":"function","title":"ExTypesense.upsert_collection_alias/2","doc":"See  ExTypesense.Collection.upsert_collection_alias/2 .","ref":"ExTypesense.html#upsert_collection_alias/2"},{"type":"function","title":"ExTypesense.upsert_collection_alias/3","doc":"See  ExTypesense.Collection.upsert_collection_alias/3 .","ref":"ExTypesense.html#upsert_collection_alias/3"},{"type":"function","title":"ExTypesense.upsert_override/3","doc":"See  ExTypesense.Curation.upsert_override/3 .","ref":"ExTypesense.html#upsert_override/3"},{"type":"function","title":"ExTypesense.upsert_override/4","doc":"See  ExTypesense.Curation.upsert_override/4 .","ref":"ExTypesense.html#upsert_override/4"},{"type":"function","title":"ExTypesense.upsert_preset/2","doc":"See  ExTypesense.Preset.upsert_preset/2 .","ref":"ExTypesense.html#upsert_preset/2"},{"type":"function","title":"ExTypesense.upsert_preset/3","doc":"See  ExTypesense.Preset.upsert_preset/3 .","ref":"ExTypesense.html#upsert_preset/3"},{"type":"function","title":"ExTypesense.upsert_stopword/2","doc":"See  ExTypesense.Stopwords.upsert_stopword/2 .","ref":"ExTypesense.html#upsert_stopword/2"},{"type":"function","title":"ExTypesense.upsert_stopword/3","doc":"See  ExTypesense.Stopwords.upsert_stopword/3 .","ref":"ExTypesense.html#upsert_stopword/3"},{"type":"function","title":"ExTypesense.upsert_synonym/3","doc":"See  ExTypesense.Synonym.upsert_synonym/3 .","ref":"ExTypesense.html#upsert_synonym/3"},{"type":"function","title":"ExTypesense.upsert_synonym/4","doc":"See  ExTypesense.Synonym.upsert_synonym/4 .","ref":"ExTypesense.html#upsert_synonym/4"},{"type":"function","title":"ExTypesense.vote/0","doc":"See  ExTypesense.Cluster.vote/0 .","ref":"ExTypesense.html#vote/0"},{"type":"function","title":"ExTypesense.vote/1","doc":"See  ExTypesense.Cluster.vote/1 .","ref":"ExTypesense.html#vote/1"},{"type":"module","title":"ExTypesense.Analytics","doc":"Typesense can aggregate search queries for both analytics\npurposes and for query suggestions.\n\nMore here: https://typesense.org/docs/latest/api/analytics-query-suggestions.html","ref":"ExTypesense.Analytics.html"},{"type":"function","title":"ExTypesense.Analytics.create_analytics_event/1","doc":"Create an analytics event\n\nSending events for analytics e.g rank search results based on popularity.","ref":"ExTypesense.Analytics.html#create_analytics_event/1"},{"type":"function","title":"Examples - ExTypesense.Analytics.create_analytics_event/1","doc":"iex> body =\n    ...>   %{\n    ...>     \"name\" => event_name,\n    ...>     \"type\" => \"click\",\n    ...>     \"data\" => %{\n    ...>       \"q\" => \"nike_shoes\",\n    ...>       \"doc_id\" => \"2468\",\n    ...>       \"user_id\" => \"9903\"\n    ...>     }\n    ...>   }\n    iex> ExTypesense.create_analytics_event(body)","ref":"ExTypesense.Analytics.html#create_analytics_event/1-examples"},{"type":"function","title":"ExTypesense.Analytics.create_analytics_event/2","doc":"Same as [create_analytics_event/1](`create_analytics_event/1`)","ref":"ExTypesense.Analytics.html#create_analytics_event/2"},{"type":"function","title":"Options - ExTypesense.Analytics.create_analytics_event/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Analytics.html#create_analytics_event/2-options"},{"type":"function","title":"Examples - ExTypesense.Analytics.create_analytics_event/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.create_analytics_event(body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.create_analytics_event(body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.create_analytics_event(body, opts)","ref":"ExTypesense.Analytics.html#create_analytics_event/2-examples"},{"type":"function","title":"ExTypesense.Analytics.create_analytics_rule/1","doc":"Creates an analytics rule\n\nWhen an analytics rule is created, we give it a name and\ndescribe the type, the source collections and the\ndestination collection.","ref":"ExTypesense.Analytics.html#create_analytics_rule/1"},{"type":"function","title":"Examples - ExTypesense.Analytics.create_analytics_rule/1","doc":"iex> body = %{\n    ...>   \"name\" => name,\n    ...>   \"type\" => \"counter\",\n    ...>   \"params\" => %{\n    ...>     \"source\" => %{\n    ...>       \"collections\" => [\"products\"],\n    ...>       \"events\" => [\n    ...>         %{\"type\" => \"click\", \"weight\" => 1, \"name\" => event_name}\n    ...>       ]\n    ...>     },\n    ...>     \"destination\" => %{\n    ...>       \"collection\" => \"products\",\n    ...>       \"counter_field\" => \"popularity\"\n    ...>     }\n    ...>   }\n    ...> }\n\n    iex> ExTypesense.create_analytics_rule(body)","ref":"ExTypesense.Analytics.html#create_analytics_rule/1-examples"},{"type":"function","title":"ExTypesense.Analytics.create_analytics_rule/2","doc":"Same as [create_analytics_rule/1](`create_analytics_rule/1`)","ref":"ExTypesense.Analytics.html#create_analytics_rule/2"},{"type":"function","title":"Options - ExTypesense.Analytics.create_analytics_rule/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Analytics.html#create_analytics_rule/2-options"},{"type":"function","title":"Examples - ExTypesense.Analytics.create_analytics_rule/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.create_analytics_rule(body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.create_analytics_rule(body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.create_analytics_rule(body, opts)","ref":"ExTypesense.Analytics.html#create_analytics_rule/2-examples"},{"type":"function","title":"ExTypesense.Analytics.delete_analytics_rule/1","doc":"Delete an analytics rule\n\nPermanently deletes an analytics rule, given it's name","ref":"ExTypesense.Analytics.html#delete_analytics_rule/1"},{"type":"function","title":"ExTypesense.Analytics.delete_analytics_rule/2","doc":"Same as [delete_analytics_rule/1](`delete_analytics_rule/1`)","ref":"ExTypesense.Analytics.html#delete_analytics_rule/2"},{"type":"function","title":"Options - ExTypesense.Analytics.delete_analytics_rule/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Analytics.html#delete_analytics_rule/2-options"},{"type":"function","title":"Examples - ExTypesense.Analytics.delete_analytics_rule/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_analytics_rule(rule_name, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_analytics_rule(rule_name, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_analytics_rule(rule_name, opts)","ref":"ExTypesense.Analytics.html#delete_analytics_rule/2-examples"},{"type":"function","title":"ExTypesense.Analytics.get_analytics_rule/1","doc":"Retrieve the details of an analytics rule, given it's name","ref":"ExTypesense.Analytics.html#get_analytics_rule/1"},{"type":"function","title":"Examples - ExTypesense.Analytics.get_analytics_rule/1","doc":"iex> ExTypesense.get_analytics_rule(rule_name)","ref":"ExTypesense.Analytics.html#get_analytics_rule/1-examples"},{"type":"function","title":"ExTypesense.Analytics.get_analytics_rule/2","doc":"Same as [get_analytics_rule/1](`get_analytics_rule/1`)","ref":"ExTypesense.Analytics.html#get_analytics_rule/2"},{"type":"function","title":"Options - ExTypesense.Analytics.get_analytics_rule/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Analytics.html#get_analytics_rule/2-options"},{"type":"function","title":"Examples - ExTypesense.Analytics.get_analytics_rule/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_analytics_rule(rule_name, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_analytics_rule(rule_name, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_analytics_rule(rule_name, opts)","ref":"ExTypesense.Analytics.html#get_analytics_rule/2-examples"},{"type":"function","title":"ExTypesense.Analytics.list_analytics_rules/0","doc":"Retrieve the details of all analytics rules","ref":"ExTypesense.Analytics.html#list_analytics_rules/0"},{"type":"function","title":"Examples - ExTypesense.Analytics.list_analytics_rules/0","doc":"iex> ExTypesense.list_analytics_rules()","ref":"ExTypesense.Analytics.html#list_analytics_rules/0-examples"},{"type":"function","title":"ExTypesense.Analytics.list_analytics_rules/1","doc":"Same as [list_analytics_rules/0](`list_analytics_rules/0`)","ref":"ExTypesense.Analytics.html#list_analytics_rules/1"},{"type":"function","title":"Options - ExTypesense.Analytics.list_analytics_rules/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Analytics.html#list_analytics_rules/1-options"},{"type":"function","title":"Examples - ExTypesense.Analytics.list_analytics_rules/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_analytics_rules(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_analytics_rules(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_analytics_rules(opts)","ref":"ExTypesense.Analytics.html#list_analytics_rules/1-examples"},{"type":"function","title":"ExTypesense.Analytics.upsert_analytics_rule/2","doc":"Upserts an analytics rule with the given name.","ref":"ExTypesense.Analytics.html#upsert_analytics_rule/2"},{"type":"function","title":"ExTypesense.Analytics.upsert_analytics_rule/3","doc":"Same as [upsert_analytics_rule/2](`upsert_analytics_rule/2`)","ref":"ExTypesense.Analytics.html#upsert_analytics_rule/3"},{"type":"function","title":"Options - ExTypesense.Analytics.upsert_analytics_rule/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Analytics.html#upsert_analytics_rule/3-options"},{"type":"function","title":"Examples - ExTypesense.Analytics.upsert_analytics_rule/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.upsert_analytics_rule(rule_name, body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.upsert_analytics_rule(rule_name, body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.upsert_analytics_rule(rule_name, body, opts)","ref":"ExTypesense.Analytics.html#upsert_analytics_rule/3-examples"},{"type":"module","title":"ExTypesense.Cluster","doc":"Cluster specific operations.\n\nMore here: https://typesense.org/docs/latest/api/cluster-operations.html","ref":"ExTypesense.Cluster.html"},{"type":"function","title":"ExTypesense.Cluster.api_stats/0","doc":"Get stats about API endpoints.\n\nThis endpoint returns average requests per second and\nlatencies for all requests in the last 10 seconds.","ref":"ExTypesense.Cluster.html#api_stats/0"},{"type":"function","title":"Examples - ExTypesense.Cluster.api_stats/0","doc":"iex> ExTypesense.api_stats()","ref":"ExTypesense.Cluster.html#api_stats/0-examples"},{"type":"function","title":"ExTypesense.Cluster.api_stats/1","doc":"Same as [api_stats/0](`api_stats/0`)","ref":"ExTypesense.Cluster.html#api_stats/1"},{"type":"function","title":"Options - ExTypesense.Cluster.api_stats/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#api_stats/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.api_stats/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.api_stats(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.api_stats(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.api_stats(opts)","ref":"ExTypesense.Cluster.html#api_stats/1-examples"},{"type":"function","title":"ExTypesense.Cluster.clear_cache/0","doc":"Clears the cache\n\nResponses of search requests that are sent with\n[`use_cache` parameter](https://typesense.org/docs/latest/api/search.html#caching-parameters)\nare cached in a LRU cache. Clears cache completely.","ref":"ExTypesense.Cluster.html#clear_cache/0"},{"type":"function","title":"Examples - ExTypesense.Cluster.clear_cache/0","doc":"iex> ExTypesense.clear_cache()","ref":"ExTypesense.Cluster.html#clear_cache/0-examples"},{"type":"function","title":"ExTypesense.Cluster.clear_cache/1","doc":"Same as [clear_cache/0](`clear_cache/0`)","ref":"ExTypesense.Cluster.html#clear_cache/1"},{"type":"function","title":"Options - ExTypesense.Cluster.clear_cache/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#clear_cache/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.clear_cache/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.clear_cache(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.clear_cache(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.clear_cache(opts)","ref":"ExTypesense.Cluster.html#clear_cache/1-examples"},{"type":"function","title":"ExTypesense.Cluster.cluster_metrics/0","doc":"Get current RAM, CPU, Disk & Network usage metrics.","ref":"ExTypesense.Cluster.html#cluster_metrics/0"},{"type":"function","title":"Examples - ExTypesense.Cluster.cluster_metrics/0","doc":"iex> ExTypesense.cluster_metrics()","ref":"ExTypesense.Cluster.html#cluster_metrics/0-examples"},{"type":"function","title":"ExTypesense.Cluster.cluster_metrics/1","doc":"Same as [cluster_metrics/0](`cluster_metrics/0`)","ref":"ExTypesense.Cluster.html#cluster_metrics/1"},{"type":"function","title":"Options - ExTypesense.Cluster.cluster_metrics/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#cluster_metrics/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.cluster_metrics/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.cluster_metrics(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.cluster_metrics(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.cluster_metrics(opts)","ref":"ExTypesense.Cluster.html#cluster_metrics/1-examples"},{"type":"function","title":"ExTypesense.Cluster.compact_db/0","doc":"[Compaction](https://typesense.org/docs/latest/api/cluster-operations.html#compacting-the-on-disk-database)\nof the underlying RocksDB database.\n\nTypesense uses RocksDB to store your documents on the disk. If you do frequent\nwrites or updates, you could benefit from running a compaction of the underlying\nRocksDB database. This could reduce the size of the database and decrease read\nlatency. While the database will not block during this operation, we recommend\nrunning it during off-peak hours.","ref":"ExTypesense.Cluster.html#compact_db/0"},{"type":"function","title":"Examples - ExTypesense.Cluster.compact_db/0","doc":"iex> ExTypesense.compact_db()","ref":"ExTypesense.Cluster.html#compact_db/0-examples"},{"type":"function","title":"ExTypesense.Cluster.compact_db/1","doc":"Same as [compact_db/0](`compact_db/0`)","ref":"ExTypesense.Cluster.html#compact_db/1"},{"type":"function","title":"Options - ExTypesense.Cluster.compact_db/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#compact_db/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.compact_db/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.compact_db(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.compact_db(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.compact_db(opts)","ref":"ExTypesense.Cluster.html#compact_db/1-examples"},{"type":"function","title":"ExTypesense.Cluster.create_snapshot/1","doc":"Creates a point-in-time snapshot of a Typesense node's state and data in the\nspecified directory.\n\nYou can then backup the snapshot directory that gets created and later restore\nit as a data directory, as needed.","ref":"ExTypesense.Cluster.html#create_snapshot/1"},{"type":"function","title":"Options - ExTypesense.Cluster.create_snapshot/1","doc":"* `conn`: The custom connection map or struct you passed\n  * `snapshot_path`: The directory on the server where the snapshot should be saved.","ref":"ExTypesense.Cluster.html#create_snapshot/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.create_snapshot/1","doc":"iex> path = \"/path/to/snapshot_dir\"\n    iex> ExTypesense.create_snapshot(snapshot_path: path)\n\n    iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.create_snapshot(snapshot_path: path, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.create_snapshot(snapshot_path: path, conn: conn)\n\n    iex> opts = [snapshot_path: path, conn: conn]\n    iex> ExTypesense.create_snapshot(opts)","ref":"ExTypesense.Cluster.html#create_snapshot/1-examples"},{"type":"function","title":"ExTypesense.Cluster.get_schema_changes/0","doc":"Get the status of in-progress schema change operations\n\nReturns the status of any ongoing schema change operations. If no schema\nchanges are in progress, returns an empty response.","ref":"ExTypesense.Cluster.html#get_schema_changes/0"},{"type":"function","title":"Examples - ExTypesense.Cluster.get_schema_changes/0","doc":"iex> ExTypesense.get_schema_changes()","ref":"ExTypesense.Cluster.html#get_schema_changes/0-examples"},{"type":"function","title":"ExTypesense.Cluster.get_schema_changes/1","doc":"Same as [get_schema_changes/0](`get_schema_changes/0`) but passes another connection.","ref":"ExTypesense.Cluster.html#get_schema_changes/1"},{"type":"function","title":"Options - ExTypesense.Cluster.get_schema_changes/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#get_schema_changes/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.get_schema_changes/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_schema_changes(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_schema_changes(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_schema_changes(opts)","ref":"ExTypesense.Cluster.html#get_schema_changes/1-examples"},{"type":"function","title":"ExTypesense.Cluster.health/0","doc":"Get health information about a Typesense node.","ref":"ExTypesense.Cluster.html#health/0"},{"type":"function","title":"Examples - ExTypesense.Cluster.health/0","doc":"iex> ExTypesense.health()","ref":"ExTypesense.Cluster.html#health/0-examples"},{"type":"function","title":"ExTypesense.Cluster.health/1","doc":"Same as [health/0](`health/0`)","ref":"ExTypesense.Cluster.html#health/1"},{"type":"function","title":"Options - ExTypesense.Cluster.health/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#health/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.health/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.health(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.health(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.health(opts)","ref":"ExTypesense.Cluster.html#health/1-examples"},{"type":"function","title":"ExTypesense.Cluster.toggle_slow_request_log/1","doc":"Enable logging of requests that take over a defined threshold of time.\n\nSlow requests are logged to the primary log file, with the prefix `SLOW REQUEST`.\nDefault is `-1` which disables slow request logging.","ref":"ExTypesense.Cluster.html#toggle_slow_request_log/1"},{"type":"function","title":"Example - ExTypesense.Cluster.toggle_slow_request_log/1","doc":"iex> config = %{\"log_slow_requests_time_ms\" => 2_000}\n    iex> ExTypesense.toggle_slow_request_log(config)","ref":"ExTypesense.Cluster.html#toggle_slow_request_log/1-example"},{"type":"function","title":"ExTypesense.Cluster.toggle_slow_request_log/2","doc":"Same as [toggle_slow_request_log/1](`toggle_slow_request_log/1`)","ref":"ExTypesense.Cluster.html#toggle_slow_request_log/2"},{"type":"function","title":"Options - ExTypesense.Cluster.toggle_slow_request_log/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#toggle_slow_request_log/2-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.toggle_slow_request_log/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.toggle_slow_request_log(config, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.toggle_slow_request_log(config, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.toggle_slow_request_log(config, opts)","ref":"ExTypesense.Cluster.html#toggle_slow_request_log/2-examples"},{"type":"function","title":"ExTypesense.Cluster.vote/0","doc":"Triggers a follower node to initiate the raft voting process, which\ntriggers leader re-election.\n\nThe follower node that you run this operation against will become\nthe new leader, once this command succeeds.","ref":"ExTypesense.Cluster.html#vote/0"},{"type":"function","title":"Examples - ExTypesense.Cluster.vote/0","doc":"iex> ExTypesense.vote()","ref":"ExTypesense.Cluster.html#vote/0-examples"},{"type":"function","title":"ExTypesense.Cluster.vote/1","doc":"Same as [vote/0](`vote/0`) but passes another connection.","ref":"ExTypesense.Cluster.html#vote/1"},{"type":"function","title":"Options - ExTypesense.Cluster.vote/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Cluster.html#vote/1-options"},{"type":"function","title":"Examples - ExTypesense.Cluster.vote/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.vote(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.vote(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.vote(opts)","ref":"ExTypesense.Cluster.html#vote/1-examples"},{"type":"module","title":"ExTypesense.Collection","doc":"Module for creating, listing and deleting collections and aliases.\n\nIn Typesense, a [Collection](https://typesense.org/docs/latest/api/collections.html)\nis a group of related [Documents](https://typesense.org/docs/latest/api/documents.html)\nthat is roughly equivalent to a table in a relational database. When\nwe create a collection, we give it a name and describe the fields\nthat will be indexed when a document is added to the collection.\n\nMore here: https://typesense.org/docs/latest/api/collections.html","ref":"ExTypesense.Collection.html"},{"type":"function","title":"ExTypesense.Collection.clone_collection/2","doc":"Clone an existing collection's schema (documents are not copied),\noverrides and synonyms. The actual documents in the collection are\nnot copied, so this is primarily useful for creating new\ncollections from an existing reference template.","ref":"ExTypesense.Collection.html#clone_collection/2"},{"type":"function","title":"Examples - ExTypesense.Collection.clone_collection/2","doc":"iex> ExTypesense.clone_collection(MyModule.Accounts.User, \"persons\")\n    iex> ExTypesense.clone_collection(\"persons\", \"accounts\")","ref":"ExTypesense.Collection.html#clone_collection/2-examples"},{"type":"function","title":"ExTypesense.Collection.clone_collection/3","doc":"Same as [clone_collection/2](`clone_collection/2`)","ref":"ExTypesense.Collection.html#clone_collection/3"},{"type":"function","title":"Options - ExTypesense.Collection.clone_collection/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#clone_collection/3-options"},{"type":"function","title":"Examples - ExTypesense.Collection.clone_collection/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.clone_collection(\"persons\", \"accounts\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.clone_collection(MyModule.Accounts.User, \"persons\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.clone_collection(MyModule.Accounts.User, \"persons\", opts)","ref":"ExTypesense.Collection.html#clone_collection/3-examples"},{"type":"function","title":"ExTypesense.Collection.create_collection/1","doc":"Create collection from a map, or module name. Collection name\nis matched on table name if using Ecto schema by default.\n\nPlease refer to these [list of schema params](https://typesense.org/docs/latest/api/collections.html#schema-parameters).","ref":"ExTypesense.Collection.html#create_collection/1"},{"type":"function","title":"Examples - ExTypesense.Collection.create_collection/1","doc":"iex> schema = %{\n    ...>   name: \"companies\",\n    ...>   fields: [\n    ...>     %{name: \"company_name\", type: \"string\"},\n    ...>     %{name: \"companies_id\", type: \"int32\"},\n    ...>     %{name: \"country\", type: \"string\", facet: true}\n    ...>   ],\n    ...>   default_sorting_field: \"companies_id\"\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    {:ok, %OpenApiTypesense.CollectionResponse{\n      created_at: 1234567890,\n      default_sorting_field: \"companies_id\",\n      fields: [...],\n      name: \"companies\",\n      num_documents: 0,\n      symbols_to_index: [],\n      token_separators: []\n    }}\n\n    iex> ExTypesense.create_collection(Person)\n    {:ok, %OpenApiTypesense.CollectionResponse{\n      created_at: 1234567890,\n      default_sorting_field: \"persons_id\",\n      fields: [...],\n      name: \"persons\",\n      num_documents: 0,\n      symbols_to_index: [],\n      token_separators: []\n    }}","ref":"ExTypesense.Collection.html#create_collection/1-examples"},{"type":"function","title":"ExTypesense.Collection.create_collection/2","doc":"Same as [create_collection/1](`create_collection/1`) but passes another connection or opts.","ref":"ExTypesense.Collection.html#create_collection/2"},{"type":"function","title":"Options - ExTypesense.Collection.create_collection/2","doc":"* `conn`: The custom connection map or struct you passed\n  * `src_name` (optional): Clone an existing collection's schema (documents are not copied), overrides and synonyms. This option is used primarily by [`clone_collection/2`](`clone_collection/2`).","ref":"ExTypesense.Collection.html#create_collection/2-options"},{"type":"function","title":"Examples - ExTypesense.Collection.create_collection/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.create_collection(schema, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.create_collection(schema, conn: conn)\n\n    iex> opts = [src_name: \"companies\", conn: conn]\n    iex> ExTypesense.create_collection(schema, opts)","ref":"ExTypesense.Collection.html#create_collection/2-examples"},{"type":"function","title":"ExTypesense.Collection.create_collection_with_alias/1","doc":"Creates collection with timestamped name and points to an alias.\n\n> #### Use case {: .warning}\n>\n> When using this function, it will append\n> a timestamp in name and adds an alias based on schema name.\n> E.g. if table name is \"bricks\", then collection name is \"bricks-1738558695\"\n> and alias name is \"bricks\". The reason for this addition can be useful\n> when encountering like [full re-indexing](https://typesense.org/docs/guide/syncing-data-into-typesense.html#full-re-indexing)\n\n> One common use-case for aliases is to reindex your data in the\n> background on a new collection and then switch your application\n> to it without any changes to your code. [Source](https://typesense.org/docs/latest/api/collection-alias.html#use-case)","ref":"ExTypesense.Collection.html#create_collection_with_alias/1"},{"type":"function","title":"Options - ExTypesense.Collection.create_collection_with_alias/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#create_collection_with_alias/1-options"},{"type":"function","title":"Examples - ExTypesense.Collection.create_collection_with_alias/1","doc":"iex> schema = %{\n    ...>   name: \"companies\",\n    ...>   fields: [\n    ...>     %{name: \"company_name\", type: \"string\"},\n    ...>     %{name: \"companies_id\", type: \"int32\"},\n    ...>     %{name: \"country\", type: \"string\", facet: true}\n    ...>   ],\n    ...>   default_sorting_field: \"companies_id\"\n    ...> }\n    iex> ExTypesense.create_collection_with_alias(schema)\n\n    iex> ExTypesense.create_collection_with_alias(Person)","ref":"ExTypesense.Collection.html#create_collection_with_alias/1-examples"},{"type":"function","title":"ExTypesense.Collection.create_collection_with_alias/2","doc":"Same as [create_collection_with_alias/1](`create_collection_with_alias/1`) but passes another connection or opts.","ref":"ExTypesense.Collection.html#create_collection_with_alias/2"},{"type":"function","title":"Examples - ExTypesense.Collection.create_collection_with_alias/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.create_collection_with_alias(schema, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.create_collection_with_alias(schema, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.create_collection_with_alias(schema, opts)","ref":"ExTypesense.Collection.html#create_collection_with_alias/2-examples"},{"type":"function","title":"ExTypesense.Collection.delete_collection_alias/1","doc":"Deletes a collection alias. The collection itself\nis not affected by this action.","ref":"ExTypesense.Collection.html#delete_collection_alias/1"},{"type":"function","title":"Examples - ExTypesense.Collection.delete_collection_alias/1","doc":"iex> ExTypesense.delete_collection_alias(\"persons_sept_8_2019\")","ref":"ExTypesense.Collection.html#delete_collection_alias/1-examples"},{"type":"function","title":"ExTypesense.Collection.delete_collection_alias/2","doc":"Same as [delete_collection_alias/1](`delete_collection_alias/1`)","ref":"ExTypesense.Collection.html#delete_collection_alias/2"},{"type":"function","title":"Options - ExTypesense.Collection.delete_collection_alias/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#delete_collection_alias/2-options"},{"type":"function","title":"Examples - ExTypesense.Collection.delete_collection_alias/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_collection_alias(\"persons_sept_8_2019\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_collection_alias(\"persons_sept_8_2019\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_collection_alias(\"persons_sept_8_2019\", opts)","ref":"ExTypesense.Collection.html#delete_collection_alias/2-examples"},{"type":"function","title":"ExTypesense.Collection.drop_collection/1","doc":"Permanently drops a collection by collection name or module name.\n\nThis action **cannot** be undone. For large collections, this might\nhave an impact on read latencies.\n\n> #### alias not affected {: .tip}\n>\n> dropping a collection does not remove the referenced\n> alias, only the indexed documents.","ref":"ExTypesense.Collection.html#drop_collection/1"},{"type":"function","title":"Examples - ExTypesense.Collection.drop_collection/1","doc":"iex> ExTypesense.drop_collection(\"persons\")\n\n    iex> ExTypesense.drop_collection(MyModule.Accounts.User)","ref":"ExTypesense.Collection.html#drop_collection/1-examples"},{"type":"function","title":"ExTypesense.Collection.drop_collection/2","doc":"Same as [drop_collection/2](`drop_collection/2`)","ref":"ExTypesense.Collection.html#drop_collection/2"},{"type":"function","title":"Options - ExTypesense.Collection.drop_collection/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#drop_collection/2-options"},{"type":"function","title":"Examples - ExTypesense.Collection.drop_collection/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.drop_collection(\"persons\", conn: conn)\n\n    iex> ExTypesense.drop_collection(\"persons\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.drop_collection(MyModule.Accounts.User, opts)","ref":"ExTypesense.Collection.html#drop_collection/2-examples"},{"type":"function","title":"ExTypesense.Collection.get_collection/1","doc":"Get a specific collection by string or module name.","ref":"ExTypesense.Collection.html#get_collection/1"},{"type":"function","title":"Examples - ExTypesense.Collection.get_collection/1","doc":"iex> ExTypesense.get_collection(MyModule.Accounts.User)\n    iex> ExTypesense.get_collection(\"persons\")","ref":"ExTypesense.Collection.html#get_collection/1-examples"},{"type":"function","title":"ExTypesense.Collection.get_collection/2","doc":"Same as [get_collection/1](`get_collection/1`)","ref":"ExTypesense.Collection.html#get_collection/2"},{"type":"function","title":"Options - ExTypesense.Collection.get_collection/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#get_collection/2-options"},{"type":"function","title":"Examples - ExTypesense.Collection.get_collection/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_collection(\"persons\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_collection(MyModule.Accounts.User, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_collection(MyModule.Accounts.User, opts)","ref":"ExTypesense.Collection.html#get_collection/2-examples"},{"type":"function","title":"ExTypesense.Collection.get_collection_alias/1","doc":"Get a specific collection by alias.","ref":"ExTypesense.Collection.html#get_collection_alias/1"},{"type":"function","title":"Examples - ExTypesense.Collection.get_collection_alias/1","doc":"iex> ExTypesense.get_collection_alias(\"persons_sept_8_2019\")","ref":"ExTypesense.Collection.html#get_collection_alias/1-examples"},{"type":"function","title":"ExTypesense.Collection.get_collection_alias/2","doc":"Same as [get_collection_alias/1](`get_collection_alias/1`)","ref":"ExTypesense.Collection.html#get_collection_alias/2"},{"type":"function","title":"Options - ExTypesense.Collection.get_collection_alias/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#get_collection_alias/2-options"},{"type":"function","title":"Examples - ExTypesense.Collection.get_collection_alias/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_collection_alias(\"persons_sept_8_2019\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_collection_alias(\"persons_sept_8_2019\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_collection_alias(\"persons_sept_8_2019\", opts)","ref":"ExTypesense.Collection.html#get_collection_alias/2-examples"},{"type":"function","title":"ExTypesense.Collection.list_collection_aliases/0","doc":"List all aliases and the corresponding collections that they map to.","ref":"ExTypesense.Collection.html#list_collection_aliases/0"},{"type":"function","title":"Examples - ExTypesense.Collection.list_collection_aliases/0","doc":"iex> ExTypesense.list_collection_aliases()","ref":"ExTypesense.Collection.html#list_collection_aliases/0-examples"},{"type":"function","title":"ExTypesense.Collection.list_collection_aliases/1","doc":"Same as [list_collection_aliases/0](`list_collection_aliases/0`)","ref":"ExTypesense.Collection.html#list_collection_aliases/1"},{"type":"function","title":"Options - ExTypesense.Collection.list_collection_aliases/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#list_collection_aliases/1-options"},{"type":"function","title":"Examples - ExTypesense.Collection.list_collection_aliases/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_collection_aliases(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_collection_aliases(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_collection_aliases(opts)","ref":"ExTypesense.Collection.html#list_collection_aliases/1-examples"},{"type":"function","title":"ExTypesense.Collection.list_collections/0","doc":"Returns a summary of all your collections. The collections are returned\nsorted by creation date, with the most recent collections appearing first.","ref":"ExTypesense.Collection.html#list_collections/0"},{"type":"function","title":"Examples - ExTypesense.Collection.list_collections/0","doc":"iex> ExTypesense.list_collections()","ref":"ExTypesense.Collection.html#list_collections/0-examples"},{"type":"function","title":"ExTypesense.Collection.list_collections/1","doc":"Same as [list_collections/0](`list_collections/0`) but passes another connection or option.","ref":"ExTypesense.Collection.html#list_collections/1"},{"type":"function","title":"Options - ExTypesense.Collection.list_collections/1","doc":"* `conn`: The custom connection map or struct you passed\n* `limit`: Limit results in paginating on collection listing.\n* `offset`: Skip a certain number of results and start after that.\n* `exclude_fields`: Exclude the field definitions from being returned in the response.","ref":"ExTypesense.Collection.html#list_collections/1-options"},{"type":"function","title":"Examples - ExTypesense.Collection.list_collections/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_collections(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_collections(conn: conn)\n\n    iex> opts = [exclude_fields: \"fields\", limit: 10, conn: conn]\n    iex> ExTypesense.list_collections(opts)","ref":"ExTypesense.Collection.html#list_collections/1-examples"},{"type":"function","title":"ExTypesense.Collection.update_collection_fields/2","doc":"Make changes in a collection's fields: adding, removing\nor updating an existing field(s). Key name is `drop` to\nindicate which field is removed (example described below).\nOnly `fields` can only be updated at the moment.\n\n> #### Typesense special field `id` {: .info}\n>\n> Typesense supports updating all fields\n> except the `id` field (since it's a special field\n> within Typesense). Do not confuse `id` of Typesense\n> with Ecto Schema or DB record(s).\n\n\n> #### Which version supports this function {: .info}\n>\n> We can update the collection's fields, starting on version\n> [27.0.rc22](https://github.com/typesense/typesense/issues/1700#issuecomment-2200125617)\n> and above.","ref":"ExTypesense.Collection.html#update_collection_fields/2"},{"type":"function","title":"Examples - ExTypesense.Collection.update_collection_fields/2","doc":"iex> fields = %{\n    ...>  fields: [\n    ...>    %{name: \"num_employees\", drop: true},\n    ...>    %{name: \"company_category\", type: \"string\"},\n    ...>  ],\n    ...> }\n    iex> ExTypesense.update_collection_fields(\"companies\", fields)\n    %OpenApiTypesense.CollectionUpdateSchema{\n      fields: [\n        ...\n      ]\n    }","ref":"ExTypesense.Collection.html#update_collection_fields/2-examples"},{"type":"function","title":"ExTypesense.Collection.update_collection_fields/3","doc":"Same as [update_collection_fields/2](`update_collection_fields/2`)","ref":"ExTypesense.Collection.html#update_collection_fields/3"},{"type":"function","title":"Options - ExTypesense.Collection.update_collection_fields/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#update_collection_fields/3-options"},{"type":"function","title":"Examples - ExTypesense.Collection.update_collection_fields/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.update_collection_fields(\"persons\", fields, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.update_collection_fields(\"persons\", fields, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_collection(\"persons\", fields, opts)","ref":"ExTypesense.Collection.html#update_collection_fields/3-examples"},{"type":"function","title":"ExTypesense.Collection.upsert_collection_alias/2","doc":"Upserts a collection alias.\n\nAn alias is a virtual collection name that points to a real collection. If you're familiar\nwith symbolic links on Linux, it's very similar to that. Aliases are useful when you want\nto reindex your data in the background on a new collection and switch your application to\nit without any changes to your code.\n\n`collection_name` can either be a string or module name","ref":"ExTypesense.Collection.html#upsert_collection_alias/2"},{"type":"function","title":"Examples - ExTypesense.Collection.upsert_collection_alias/2","doc":"iex> ExTypesense.upsert_collection_alias(\"persons_sept_8_2019\", \"persons\")","ref":"ExTypesense.Collection.html#upsert_collection_alias/2-examples"},{"type":"function","title":"ExTypesense.Collection.upsert_collection_alias/3","doc":"Same as [upsert_collection_alias/2](`upsert_collection_alias/2`)","ref":"ExTypesense.Collection.html#upsert_collection_alias/3"},{"type":"function","title":"Options - ExTypesense.Collection.upsert_collection_alias/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Collection.html#upsert_collection_alias/3-options"},{"type":"function","title":"Examples - ExTypesense.Collection.upsert_collection_alias/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.upsert_collection_alias(\"persons_sept_8_2019\", \"persons\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.upsert_collection_alias(\"persons_sept_8_2019\", MyModule.Accounts.Person, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.upsert_collection_alias(\"persons_sept_8_2019\", \"persons\", opts)","ref":"ExTypesense.Collection.html#upsert_collection_alias/3-examples"},{"type":"module","title":"ExTypesense.Conversation","doc":"Typesense has the ability to respond to free-form questions,\nwith conversational responses and also maintain context for\nfollow-up questions and answers.\n\nMore here: https://typesense.org/docs/latest/api/conversational-search-rag.html","ref":"ExTypesense.Conversation.html"},{"type":"function","title":"ExTypesense.Conversation.create_model/1","doc":"Create conversation model.\n\nTypesense currently supports the following LLM platforms:\n\n- [OpenAI](https://platform.openai.com/docs/models/models-overview)\n- [Cloudflare Workers AI](https://developers.cloudflare.com/workers-ai/models/#text-generation)\n- [vLLM](https://github.com/vllm-project/vllm)(useful when running local LLMs)","ref":"ExTypesense.Conversation.html#create_model/1"},{"type":"function","title":"Examples - ExTypesense.Conversation.create_model/1","doc":"iex> body = %{\n    ...>   \"id\" => \"conv-model-1\",\n    ...>   \"model_name\" => \"openai/gpt-3.5-turbo\",\n    ...>   \"history_collection\" => \"conversation_store\",\n    ...>   \"api_key\" => \"OPENAI_API_KEY\",\n    ...>   \"system_prompt\" => \"You are an assistant for question-answering. You can only make conversations based on the provided context. If a response cannot be formed strictly using the provided context, politely say you do not have knowledge about that topic.\",\n    ...>   \"max_bytes\" => 16_384\n    ...> }\n    iex> ExTypesense.create_model(body)","ref":"ExTypesense.Conversation.html#create_model/1-examples"},{"type":"function","title":"ExTypesense.Conversation.create_model/2","doc":"Same as [create_model/1](`create_model/1`)","ref":"ExTypesense.Conversation.html#create_model/2"},{"type":"function","title":"Options - ExTypesense.Conversation.create_model/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Conversation.html#create_model/2-options"},{"type":"function","title":"Examples - ExTypesense.Conversation.create_model/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.create_model(body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.create_model(body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.create_model(body, opts)","ref":"ExTypesense.Conversation.html#create_model/2-examples"},{"type":"function","title":"ExTypesense.Conversation.delete_model/1","doc":"Delete a conversation model","ref":"ExTypesense.Conversation.html#delete_model/1"},{"type":"function","title":"ExTypesense.Conversation.delete_model/2","doc":"Same as [delete_model/1](`delete_model/1`)","ref":"ExTypesense.Conversation.html#delete_model/2"},{"type":"function","title":"Options - ExTypesense.Conversation.delete_model/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Conversation.html#delete_model/2-options"},{"type":"function","title":"Examples - ExTypesense.Conversation.delete_model/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_model(model_id, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_model(model_id, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_model(model_id, opts)","ref":"ExTypesense.Conversation.html#delete_model/2-examples"},{"type":"function","title":"ExTypesense.Conversation.get_model/1","doc":"Retrieve a conversation model","ref":"ExTypesense.Conversation.html#get_model/1"},{"type":"function","title":"ExTypesense.Conversation.get_model/2","doc":"Same as [get_model/1](`get_model/1`)","ref":"ExTypesense.Conversation.html#get_model/2"},{"type":"function","title":"Options - ExTypesense.Conversation.get_model/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Conversation.html#get_model/2-options"},{"type":"function","title":"Examples - ExTypesense.Conversation.get_model/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_model(\"conv-model-1\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_model(\"conv-model-1\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_model(\"conv-model-1\", opts)","ref":"ExTypesense.Conversation.html#get_model/2-examples"},{"type":"function","title":"ExTypesense.Conversation.list_models/0","doc":"Retrieve all conversation models","ref":"ExTypesense.Conversation.html#list_models/0"},{"type":"function","title":"ExTypesense.Conversation.list_models/1","doc":"Same as [list_models/0](`list_models/0`)","ref":"ExTypesense.Conversation.html#list_models/1"},{"type":"function","title":"Options - ExTypesense.Conversation.list_models/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Conversation.html#list_models/1-options"},{"type":"function","title":"Examples - ExTypesense.Conversation.list_models/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_models(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_models(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_models(opts)","ref":"ExTypesense.Conversation.html#list_models/1-examples"},{"type":"function","title":"ExTypesense.Conversation.update_model/2","doc":"Update a conversation model","ref":"ExTypesense.Conversation.html#update_model/2"},{"type":"function","title":"Examples - ExTypesense.Conversation.update_model/2","doc":"iex>model_id = \"conv-model-1\"\n    iex> body = %{\n    ...>   \"id\" => model_id,\n    ...>   \"model_name\" => \"openai/gpt-3.5-turbo\",\n    ...>   \"history_collection\" => \"conversation_store\",\n    ...>   \"api_key\" => \"OPENAI_API_KEY\",\n    ...>   \"system_prompt\" => \"Hey, you are an **intelligent** assistant for question-answering. You can only make conversations based on the provided context. If a response cannot be formed strictly using the provided context, politely say you do not have knowledge about that topic.\",\n    ...>  \"max_bytes\" => 16_384\n    ...> }\n    iex> ExTypesense.update_model(model_id, body)","ref":"ExTypesense.Conversation.html#update_model/2-examples"},{"type":"function","title":"ExTypesense.Conversation.update_model/3","doc":"Same as [update_model/2](`update_model/2`)","ref":"ExTypesense.Conversation.html#update_model/3"},{"type":"function","title":"Options - ExTypesense.Conversation.update_model/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Conversation.html#update_model/3-options"},{"type":"function","title":"Examples - ExTypesense.Conversation.update_model/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.update_model(model_id, body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.update_model(model_id, body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.update_model(model_id, body, opts)","ref":"ExTypesense.Conversation.html#update_model/3-examples"},{"type":"module","title":"ExTypesense.Curation","doc":"While Typesense makes it really easy and intuitive to deliver\ngreat search results, sometimes you might want to promote\ncertain documents over others. Or, you might want to exclude\ncertain documents from a query's result set.\n\nUsing overrides, you can include or exclude specific documents\nfor a given query.\n\nMore here: https://typesense.org/docs/latest/api/curation.html#create-or-update-an-override","ref":"ExTypesense.Curation.html"},{"type":"function","title":"ExTypesense.Curation.delete_override/2","doc":"Delete an override associated with a collection","ref":"ExTypesense.Curation.html#delete_override/2"},{"type":"function","title":"ExTypesense.Curation.delete_override/3","doc":"Same as [delete_override/2](`delete_override/2`)","ref":"ExTypesense.Curation.html#delete_override/3"},{"type":"function","title":"Options - ExTypesense.Curation.delete_override/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Curation.html#delete_override/3-options"},{"type":"function","title":"Examples - ExTypesense.Curation.delete_override/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_override(\"persons\", \"person-override\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_override(\"persons\", \"person-override\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_override(MyApp.Accounts.Person, \"person-override\", opts)","ref":"ExTypesense.Curation.html#delete_override/3-examples"},{"type":"function","title":"ExTypesense.Curation.get_override/2","doc":"Retrieve the details of a search override, given its id.","ref":"ExTypesense.Curation.html#get_override/2"},{"type":"function","title":"ExTypesense.Curation.get_override/3","doc":"Same as [get_override/2](`get_override/2`)","ref":"ExTypesense.Curation.html#get_override/3"},{"type":"function","title":"Options - ExTypesense.Curation.get_override/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Curation.html#get_override/3-options"},{"type":"function","title":"Examples - ExTypesense.Curation.get_override/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_override(\"helmets\", \"custom-helmet\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_override(\"helmets\", \"custom-helmet\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_override(MyApp.Wearables.Helmet, \"custom-helmet\", opts)","ref":"ExTypesense.Curation.html#get_override/3-examples"},{"type":"function","title":"ExTypesense.Curation.list_overrides/1","doc":"Listing all overrides associated with a given collection.\n\n> #### Error {: .info}\n>\n> By default, **ALL** overrides are returned, but you can use the\n> `offset` and `limit` parameters to paginate on the listing.","ref":"ExTypesense.Curation.html#list_overrides/1"},{"type":"function","title":"Options - ExTypesense.Curation.list_overrides/1","doc":"* `limit`: Limit results in paginating on collection listing.\n  * `offset`: Skip a certain number of results and start after that.","ref":"ExTypesense.Curation.html#list_overrides/1-options"},{"type":"function","title":"ExTypesense.Curation.list_overrides/2","doc":"Same as [list_overrides/1](`list_overrides/1`).","ref":"ExTypesense.Curation.html#list_overrides/2"},{"type":"function","title":"Options - ExTypesense.Curation.list_overrides/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Curation.html#list_overrides/2-options"},{"type":"function","title":"Examples - ExTypesense.Curation.list_overrides/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_overrides(\"persons\", limit: 10, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_overrides(\"persons\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_overrides(MyApp.Accounts.Person, opts)","ref":"ExTypesense.Curation.html#list_overrides/2-examples"},{"type":"function","title":"ExTypesense.Curation.upsert_override/3","doc":"Create or update an override to promote certain documents over\nothers. Using overrides, you can include or exclude specific\ndocuments for a given query.","ref":"ExTypesense.Curation.html#upsert_override/3"},{"type":"function","title":"Examples - ExTypesense.Curation.upsert_override/3","doc":"iex> body = %{\n    ...>     \"rule\" => %{\n    ...>       \"query\" => \"Grocter and Pamble\",\n    ...>       \"match\" => \"exact\"\n    ...>     },\n    ...>     \"includes\" => [\n    ...>       %{\"id\" => \"2\", \"position\" => 44},\n    ...>       %{\"id\" => \"4\", \"position\" => 10}\n    ...>     ],\n    ...>     \"excludes\" => [\n    ...>       %{\"id\" => \"117\"}\n    ...>     ]\n    ...> }\n    iex> ExTypesense.upsert_override(\"companies\", \"cust-company\", body)","ref":"ExTypesense.Curation.html#upsert_override/3-examples"},{"type":"function","title":"ExTypesense.Curation.upsert_override/4","doc":"Same as [upsert_override/3](`upsert_override/3`)","ref":"ExTypesense.Curation.html#upsert_override/4"},{"type":"function","title":"Options - ExTypesense.Curation.upsert_override/4","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Curation.html#upsert_override/4-options"},{"type":"function","title":"Examples - ExTypesense.Curation.upsert_override/4","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.upsert_override(\"helmets\", \"custom-helmet\", body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.upsert_override(\"helmets\", \"custom-helmet\", body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.upsert_override(MyApp.Wearables.Helmet, \"custom-helmet\", body, opts)","ref":"ExTypesense.Curation.html#upsert_override/4-examples"},{"type":"module","title":"ExTypesense.Debug","doc":"Provides API endpoint related to debug","ref":"ExTypesense.Debug.html"},{"type":"function","title":"ExTypesense.Debug.debug/0","doc":"Print debugging information","ref":"ExTypesense.Debug.html#debug/0"},{"type":"function","title":"ExTypesense.Debug.debug/1","doc":"Same as [debug/0](`debug/0`)","ref":"ExTypesense.Debug.html#debug/1"},{"type":"function","title":"Options - ExTypesense.Debug.debug/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Debug.html#debug/1-options"},{"type":"function","title":"Examples - ExTypesense.Debug.debug/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.debug(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.debug(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.debug(opts)","ref":"ExTypesense.Debug.html#debug/1-examples"},{"type":"module","title":"ExTypesense.Document","doc":"Module for CRUD operations for documents. Refer to this\n[doc guide](https://typesense.org/docs/latest/api/documents.html).","ref":"ExTypesense.Document.html"},{"type":"function","title":"ExTypesense.Document.delete_all_documents/1","doc":"Deletes all documents in a collection.\n\n> #### On using this function {: .info}\n>\n> As of this writing (v0.5.0), there's no built-in way of deleting\n> all documents via [Typesense docs](https://github.com/typesense/typesense/issues/1613#issuecomment-1994986258).\n> This function uses [`delete_documents_by_query/2`](`delete_documents_by_query/2`) under the hood.","ref":"ExTypesense.Document.html#delete_all_documents/1"},{"type":"function","title":"ExTypesense.Document.delete_all_documents/2","doc":"Same as [delete_all_documents/1](`delete_all_documents/1`).","ref":"ExTypesense.Document.html#delete_all_documents/2"},{"type":"function","title":"Options - ExTypesense.Document.delete_all_documents/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#delete_all_documents/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.delete_all_documents/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_all_documents(\"persons\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_all_documents(\"persons\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_all_documents(MyModule.Accounts.Person, opts)","ref":"ExTypesense.Document.html#delete_all_documents/2-examples"},{"type":"function","title":"ExTypesense.Document.delete_document/1","doc":"Delete an individual document from a collection by using its document ID.","ref":"ExTypesense.Document.html#delete_document/1"},{"type":"function","title":"Options - ExTypesense.Document.delete_document/1","doc":"* `ignore_not_found`: (Boolean) Ignore the error and treat the deletion as success.\n  This option is only available when payload is _map_, not _struct_.\n\n> #### Deleting a document by id {: .info}\n>\n> Deleting a document means the Typesense document ID, **NOT** the\n> ID of the record itself. If you want to delete the ID of record,\n> use [`ExTypesense.delete_documents_by_query/2`](`ExTypesense.delete_documents_by_query/2`)","ref":"ExTypesense.Document.html#delete_document/1-options"},{"type":"function","title":"Examples - ExTypesense.Document.delete_document/1","doc":"iex> ExTypesense.create_collection(Post)\n    iex> post = Post |> limit(1) |> Repo.one()\n    iex> ExTypesense.index_document(post)\n    {:ok,\n      %{\n        id: \"1\",\n        posts_id: 99,\n        title: \"our first post\",\n        collection_name: \"posts\"\n      }\n    }\n    iex> ExTypesense.delete_document(post)\n\n    iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    ...> ExTypesense.create_collection(schema)\n    iex> post =\n    ...>  %{\n    ...>    id: \"12\",\n    ...>    collection_name: \"posts\",\n    ...>    posts_id: 22,\n    ...>    title: \"the quick brown fox\"\n    ...>  }\n    iex> ExTypesense.index_document(post)\n    iex> ExTypesense.delete_document(\"posts\", \"12\", ignore_not_found: true)\n    {:ok,\n      %{\n        id: \"12\",\n        posts_id: 22,\n        title: \"the quick brown fox\",\n        collection_name: \"posts\"\n      }\n    }","ref":"ExTypesense.Document.html#delete_document/1-examples"},{"type":"function","title":"ExTypesense.Document.delete_document/2","doc":"Same as [delete_document/1](`delete_document/1`).","ref":"ExTypesense.Document.html#delete_document/2"},{"type":"function","title":"Options - ExTypesense.Document.delete_document/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#delete_document/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.delete_document/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_document(document, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_document(struct, conn: conn)\n\n    iex> opts = [ignore_not_found: true, conn: conn]\n    iex> ExTypesense.delete_document(struct, opts)","ref":"ExTypesense.Document.html#delete_document/2-examples"},{"type":"function","title":"ExTypesense.Document.delete_document/3","doc":"Same as [delete_document/2](`delete_document/2`).","ref":"ExTypesense.Document.html#delete_document/3"},{"type":"function","title":"Options - ExTypesense.Document.delete_document/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#delete_document/3-options"},{"type":"function","title":"Examples - ExTypesense.Document.delete_document/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_document(\"persons\", \"88\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_document(\"persons\", \"88\", conn: conn)\n\n    iex> opts = [ignore_not_found: true, conn: conn]\n    iex> ExTypesense.delete_document(\"persons\", \"88\", opts)","ref":"ExTypesense.Document.html#delete_document/3-examples"},{"type":"function","title":"ExTypesense.Document.delete_documents_by_query/2","doc":"Deletes documents in a collection by query.","ref":"ExTypesense.Document.html#delete_documents_by_query/2"},{"type":"function","title":"Options - ExTypesense.Document.delete_documents_by_query/2","doc":"* `conn`: The custom connection map or struct you passed\n  * `batch_size`: Batch size parameter controls the number of documents\n  that should be deleted at a time. A larger value will speed up deletions,\n  but will impact performance of other operations running on the server.\n  * `filter_by`: Filter results by a particular value(s) or logical\n  expressions. multiple conditions with &&.\n\n> #### [Filter and batch size](https://typesense.org/docs/latest/api/documents.html#delete-by-query) {: .info}\n>\n> To delete all documents in a collection, you can use a filter that\n> matches all documents in your collection. For eg, if you have an\n> int32 field called popularity in your documents, you can use\n> `filter_by: \"popularity:>0\"` to delete all documents. Or if you have a\n> bool field called `in_stock` in your documents, you can use\n> `filter_by: \"in_stock:[true,false]\"` to delete all documents.\n>\n> Use the `batch_size` to control the number of documents that should\n> deleted at a time. A larger value will speed up deletions, but will\n> impact performance of other operations running on the server.\n>\n> Filter parameters can be found here: https://typesense.org/docs/latest/api/search.html#filter-parameters","ref":"ExTypesense.Document.html#delete_documents_by_query/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.delete_documents_by_query/2","doc":"iex> query = [filter_by: \"num_employees:>100\", batch_size: 100]\n    iex> ExTypesense.delete_documents_by_query(Employee, query)\n    {:ok, [...]}\n\n    iex> conn = %{api_key: xyz, host: ...}\n    iex> opts = Keyword.put(query, :conn, conn)\n    iex> ExTypesense.delete_documents_by_query(Employee, opts)","ref":"ExTypesense.Document.html#delete_documents_by_query/2-examples"},{"type":"function","title":"ExTypesense.Document.export_documents/1","doc":"Export all documents in a collection in JSON lines format.","ref":"ExTypesense.Document.html#export_documents/1"},{"type":"function","title":"Options - ExTypesense.Document.export_documents/1","doc":"* `filter_by`: Filter conditions for refining your search results. Separate multiple conditions with &&.\n  * `include_fields`: List of fields from the document to include in the search result\n  * `exclude_fields`: List of fields from the document to exclude in the search result","ref":"ExTypesense.Document.html#export_documents/1-options"},{"type":"function","title":"ExTypesense.Document.export_documents/2","doc":"Same as [export_documents/1](`export_documents/1`).","ref":"ExTypesense.Document.html#export_documents/2"},{"type":"function","title":"Options - ExTypesense.Document.export_documents/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#export_documents/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.export_documents/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.export_documents(\"persons\", conn: conn)\n    iex> ExTypesense.export_documents(MyModule.Accounts.Person, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.export_documents(\"persons\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.export_documents(MyModule.Accounts.Person, opts)","ref":"ExTypesense.Document.html#export_documents/2-examples"},{"type":"function","title":"ExTypesense.Document.get_document/2","doc":"Fetch an individual document from a collection by using its ID.","ref":"ExTypesense.Document.html#get_document/2"},{"type":"function","title":"Options - ExTypesense.Document.get_document/2","doc":"* `include_fields`: (Comma-separated values) List of fields that should be present in the returned document.\n  * `exclude_fields`: (Comma-separated values) List of fields that should not be present in the returned document.","ref":"ExTypesense.Document.html#get_document/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.get_document/2","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    ...> ExTypesense.create_collection(schema)\n    ...> post = %{\n    ...>    id: \"22\"\n    ...>    posts_id: 444,\n    ...>    collection_name: \"posts\",\n    ...>    title: \"the quick brown fox\"\n    ...> }\n    iex> ExTypesense.index_document(post)\n    iex> ExTypesense.get_document(\"posts\", \"22\", exclude_fields: \"title,posts_id\")\n    {:ok,\n      %{\n        id: \"22\",\n        collection_name: \"posts\"\n      }\n    }","ref":"ExTypesense.Document.html#get_document/2-examples"},{"type":"function","title":"ExTypesense.Document.get_document/3","doc":"Same as [get_document/2](`get_document/2`).","ref":"ExTypesense.Document.html#get_document/3"},{"type":"function","title":"Options - ExTypesense.Document.get_document/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#get_document/3-options"},{"type":"function","title":"Examples - ExTypesense.Document.get_document/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_document(\"persons\", \"88\", exclude_fields: \"name\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_document(MyModule.Accounts.Person, \"88\", exclude_fields: \"name\", conn: conn)\n\n    iex> opts = [exclude_fields: \"name\", conn: conn]\n    iex> ExTypesense.get_document(MyModule.Accounts.Person, \"88\", opts)","ref":"ExTypesense.Document.html#get_document/3-examples"},{"type":"function","title":"ExTypesense.Document.import_documents/2","doc":"Imports/Indexes multiple documents via maps.\n\nYou can feed the output file from a Typesense export operation directly as import.","ref":"ExTypesense.Document.html#import_documents/2"},{"type":"function","title":"Options - ExTypesense.Document.import_documents/2","doc":"* `batch_size`: Batch size parameter controls the number of documents that should\n  be imported at a time. A larger value will speed up deletions, but will impact\n  performance of other operations running on the server.\n  * `return_id`: Returning the id of the imported documents. If you want the import\n  response to return the ingested document's id in the response, you can use the\n  return_id parameter.\n  * `remote_embedding_batch_size`: Max size of each batch that will be sent to remote\n  APIs while importing multiple documents at once. Using lower amount will lower\n  timeout risk, but increase number of requests made. Default is 200.\n  * `remote_embedding_timeout_ms`: How long to wait until an API call to a remote\n  embedding service is considered a timeout during indexing. Default is 60_000 ms\n  * `remote_embedding_num_tries`: The number of times to retry an API call to a remote\n  embedding service on failure during indexing. Default is 2.\n  * `return_doc`: Returns the entire document back in response.\n  * `action`: Additional action to perform\n  * `dirty_values`: Dealing with Dirty Data","ref":"ExTypesense.Document.html#import_documents/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.import_documents/2","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    ...> ExTypesense.create_collection(schema)\n\n    # doesn't matter if atom or string keys\n    # import using a list of maps\n    iex> posts = [\n    ...>   %{title: \"the quick brown fox\"},\n    ...>   %{title: \"jumps over the lazy dog\"}\n    ...> ]\n    ...> ExTypesense.import_documents(\"posts\", posts)\n    {:ok, [%{\"success\" => true}, %{\"success\" => true}]}\n\n    # import using Ecto records\n    iex> posts = MyApp.Blog.Post |> Repo.all()\n    ...> ExTypesense.import_documents(\"posts\", posts)","ref":"ExTypesense.Document.html#import_documents/2-examples"},{"type":"function","title":"ExTypesense.Document.import_documents/3","doc":"Same as [import_documents/2](`import_documents/2`).","ref":"ExTypesense.Document.html#import_documents/3"},{"type":"function","title":"Options - ExTypesense.Document.import_documents/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#import_documents/3-options"},{"type":"function","title":"Examples - ExTypesense.Document.import_documents/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.import_documents(\"users\", documents, conn: conn)\n    iex> ExTypesense.import_documents(MyApp.Accounts.User, documents, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.import_documents(MyApp.Accounts.User, structs, conn: conn)\n    iex> ExTypesense.import_documents(\"users\", [%MyApp.Accounts.User{}], conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.import_documents(\"users\", documents, opts)","ref":"ExTypesense.Document.html#import_documents/3-examples"},{"type":"function","title":"ExTypesense.Document.index_document/1","doc":"Indexes a single document using struct or map. When using struct,\nthe pk maps to document's id as string.\n\n> #### on using struct {: .info}\n>\n> Please refer on this [page](`ExTypesense`) for more info on how to\n> setup with Ecto Schema.","ref":"ExTypesense.Document.html#index_document/1"},{"type":"function","title":"Options - ExTypesense.Document.index_document/1","doc":"* `action`: \"create\" (default), \"upsert\", \"update\", \"emplace\"\n  * `dirty_values`: Dealing with Dirty Data","ref":"ExTypesense.Document.html#index_document/1-options"},{"type":"function","title":"Examples - ExTypesense.Document.index_document/1","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>     %{name: \"posts_id\", type: \"int32\"}\n    ...>     %{name: \"description\", type: \"string\"}\n    ...>   ],\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    iex> body =\n    ...>  %{\n    ...>    id: \"34\", # you can omit this key, Typesense will generate for you.\n    ...>    posts_id: 28,\n    ...>    title: \"the quick brown fox\",\n    ...>    description: \"jumps over the lazy dog\"\n    ...>  }\n    iex> ExTypesense.index_document(\"posts\", body)\n    {:ok,\n      %{\n        id: \"34\",\n        posts_id: 28,\n        title: \"the quick brown fox\",\n        description: \"jumps over the lazy dog\"\n      }\n    }\n\n    iex> doc =\n    ...>  %{\n    ...>    collection_name: \"posts\"\n    ...>    id: \"34\", # you can omit this key, Typesense will generate for you.\n    ...>    posts_id: 28,\n    ...>    title: \"the quick brown fox\",\n    ...>    description: \"jumps over the lazy dog\"\n    ...>  }\n    iex> ExTypesense.index_document(doc)\n    {:ok,\n      %{\n        id: \"34\",\n        posts_id: 28,\n        title: \"the quick brown fox\",\n        description: \"jumps over the lazy dog\"\n      }\n    }\n\n    iex> MyApp.Blog.Post |> ExTypesense.create_collection()\n    iex> post = MyApp.Blog.get_post!(24)\n    iex> ExTypesense.index_document(post)","ref":"ExTypesense.Document.html#index_document/1-examples"},{"type":"function","title":"ExTypesense.Document.index_document/2","doc":"Same as [index_document/1](`index_document/1`).","ref":"ExTypesense.Document.html#index_document/2"},{"type":"function","title":"Options - ExTypesense.Document.index_document/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#index_document/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.index_document/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.index_document(\"persons\", document, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.index_document(document, conn: conn)\n    iex> ExTypesense.index_document(struct, conn: conn)\n\n    iex> opts = [action: \"upsert\", conn: conn]\n    iex> ExTypesense.index_document(struct, opts)","ref":"ExTypesense.Document.html#index_document/2-examples"},{"type":"function","title":"ExTypesense.Document.index_document/3","doc":"Same as [index_document/2](`get_document/2`).","ref":"ExTypesense.Document.html#index_document/3"},{"type":"function","title":"Examples - ExTypesense.Document.index_document/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.index_document(\"persons\", document, action: \"update\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.index_document(\"persons\", document, conn: conn)\n\n    iex> opts = [action: \"upsert\", conn: conn]\n    iex> ExTypesense.index_document(\"persons\", document, opts)","ref":"ExTypesense.Document.html#index_document/3-examples"},{"type":"function","title":"ExTypesense.Document.update_document/1","doc":"Update an single document using struct or map. The update can be partial.\n\n**Note**: the return type for struct and map are different. See examples below.\n\n> #### indexing your document as a map {: .info}\n>\n> when using map as document, you should pass a key named `collection_name`.","ref":"ExTypesense.Document.html#update_document/1"},{"type":"function","title":"Options - ExTypesense.Document.update_document/1","doc":"* `dirty_values`: Dealing with Dirty Data","ref":"ExTypesense.Document.html#update_document/1-options"},{"type":"function","title":"Examples - ExTypesense.Document.update_document/1","doc":"iex> schema = %{\n    ...>   name: \"posts\",\n    ...>   fields: [\n    ...>     %{name: \"title\", type: \"string\"}\n    ...>   ],\n    ...> }\n    iex> ExTypesense.create_collection(schema)\n    iex> post =\n    ...>  %{\n    ...>    id: \"94\",\n    ...>    collection_name: \"posts\",\n    ...>    posts_id: 94,\n    ...>    title: \"the quick brown fox\"\n    ...>  }\n    iex> ExTypesense.index_document(post)\n    iex> updated_post =\n    ...>  %{\n    ...>    id: \"94\",\n    ...>    collection_name: \"posts\",\n    ...>    posts_id: 94,\n    ...>    title: \"test\"\n    ...>  }\n    iex> ExTypesense.update_document(updated_post)\n    {:ok,\n      %{\n        id: \"94\",\n        collection_name: \"posts\",\n        posts_id: 94,\n        title: \"sample post\"\n      }\n    }\n\n    iex> person = Accounts.fetch_person!(12)\n    ...> ExTypesense.update_document(person)\n    {:ok,\n      %OpenApiTypesense.Documents{\n        num_deleted: nil,\n        num_updated: 1\n      }\n    }","ref":"ExTypesense.Document.html#update_document/1-examples"},{"type":"function","title":"ExTypesense.Document.update_document/2","doc":"Same as [update_document/1](`update_document/1`).","ref":"ExTypesense.Document.html#update_document/2"},{"type":"function","title":"Options - ExTypesense.Document.update_document/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Document.html#update_document/2-options"},{"type":"function","title":"Examples - ExTypesense.Document.update_document/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.update_document(document, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.update_document(%User{...}, conn: conn)\n\n    iex> opts = [dirty_values: \"reject\", conn: conn]\n    iex> ExTypesense.update_document(document, opts)","ref":"ExTypesense.Document.html#update_document/2-examples"},{"type":"function","title":"ExTypesense.Document.update_documents_by_query/3","doc":"Update documents with conditional query\n\nThe filter_by query parameter is used to filter to specify a condition against which the\ndocuments are matched. The request body contains the fields that should be updated for\nany documents that match the filter condition. This endpoint is only available if the\nTypesense server is version `0.25.0.rc12` or later.\n\nSee: https://typesense.org/docs/latest/api/search.html#filter-parameters\nregarding `filter_by` option.","ref":"ExTypesense.Document.html#update_documents_by_query/3"},{"type":"function","title":"Options - ExTypesense.Document.update_documents_by_query/3","doc":"* `conn`: The custom connection map or struct you passed\n  * `filter_by`: Filter results by a particular value(s) or logical expressions.\n  multiple conditions with &&.\n  * `action`: Additional action to perform","ref":"ExTypesense.Document.html#update_documents_by_query/3-options"},{"type":"function","title":"Example - ExTypesense.Document.update_documents_by_query/3","doc":"iex> body = %{\n    ...>   \"tag\" => \"large\",\n    ...> }\n\n    iex> conn = %{api_key: xyz, host: ...}\n    iex> opts = [filter_by: \"num_employees:>1000\", conn: conn]\n    iex> ExTypesense.update_documents_by_query(\"companies\", body, opts)\n\n    iex> ExTypesense.update_documents_by_query(\"companies\", body, action: \"upsert\", conn: conn)","ref":"ExTypesense.Document.html#update_documents_by_query/3-example"},{"type":"module","title":"ExTypesense.Key","doc":"Typesense allows you to create API Keys with fine-grained access\ncontrol. You can restrict access on a per-collection, per-action,\nper-record or even per-field level or a mixture of these.\n\nMore here: https://typesense.org/docs/latest/api/api-keys.html","ref":"ExTypesense.Key.html"},{"type":"function","title":"ExTypesense.Key.create_key/1","doc":"Typesense allows you to create API Keys with fine-grained\naccess control. You can restrict access on a per-collection,\nper-action, per-record or even per-field level or a mixture\nof these.","ref":"ExTypesense.Key.html#create_key/1"},{"type":"function","title":"Examples - ExTypesense.Key.create_key/1","doc":"iex> body = %{\n    ...>   actions: [\"documents:search\"],\n    ...>   collections: [\"companies\"],\n    ...>   description: \"Search-only companies key\"\n    ...> }\n    iex> ExTypesense.create_key(body)","ref":"ExTypesense.Key.html#create_key/1-examples"},{"type":"function","title":"ExTypesense.Key.create_key/2","doc":"Same as [create_key/1](`create_key/1`)","ref":"ExTypesense.Key.html#create_key/2"},{"type":"function","title":"Options - ExTypesense.Key.create_key/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Key.html#create_key/2-options"},{"type":"function","title":"Examples - ExTypesense.Key.create_key/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.create_key(body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.create_key(body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.create_key(body, opts)","ref":"ExTypesense.Key.html#create_key/2-examples"},{"type":"function","title":"ExTypesense.Key.delete_key/1","doc":"Delete an API key given its ID.","ref":"ExTypesense.Key.html#delete_key/1"},{"type":"function","title":"ExTypesense.Key.delete_key/2","doc":"Same as [delete_key/1](`delete_key/1`)","ref":"ExTypesense.Key.html#delete_key/2"},{"type":"function","title":"Options - ExTypesense.Key.delete_key/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Key.html#delete_key/2-options"},{"type":"function","title":"Examples - ExTypesense.Key.delete_key/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_key(6, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_key(7, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_key(8, opts)","ref":"ExTypesense.Key.html#delete_key/2-examples"},{"type":"function","title":"ExTypesense.Key.get_key/1","doc":"Retrieve (metadata about) all keys.","ref":"ExTypesense.Key.html#get_key/1"},{"type":"function","title":"ExTypesense.Key.get_key/2","doc":"Same as [get_key/1](`get_key/1`)","ref":"ExTypesense.Key.html#get_key/2"},{"type":"function","title":"Options - ExTypesense.Key.get_key/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Key.html#get_key/2-options"},{"type":"function","title":"Examples - ExTypesense.Key.get_key/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_key(6, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_key(7, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_key(8, opts)","ref":"ExTypesense.Key.html#get_key/2-examples"},{"type":"function","title":"ExTypesense.Key.list_keys/0","doc":"Retrieve (metadata about) all keys.","ref":"ExTypesense.Key.html#list_keys/0"},{"type":"function","title":"ExTypesense.Key.list_keys/1","doc":"Same as [list_keys/0](`list_keys/0`)","ref":"ExTypesense.Key.html#list_keys/1"},{"type":"function","title":"Options - ExTypesense.Key.list_keys/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Key.html#list_keys/1-options"},{"type":"function","title":"Examples - ExTypesense.Key.list_keys/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_keys(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_keys(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_keys(opts)","ref":"ExTypesense.Key.html#list_keys/1-examples"},{"type":"module","title":"ExTypesense.Preset","doc":"Search presets allow you to store a bunch of search parameters\ntogether, and reference them by a name. You can then use this\npreset name when you make a search request, instead of passing\nall the search parameters individually in each search request.\n\nYou can then change the preset configuration on the Typesense\nside, to change your search parameters, without having to\nre-deploy your application.\n\nMore here: https://typesense.org/docs/latest/api/search.html#presets","ref":"ExTypesense.Preset.html"},{"type":"function","title":"ExTypesense.Preset.delete_preset/1","doc":"Permanently deletes a preset, given it's name.","ref":"ExTypesense.Preset.html#delete_preset/1"},{"type":"function","title":"ExTypesense.Preset.delete_preset/2","doc":"Same as [delete_preset/1](`delete_preset/1`)","ref":"ExTypesense.Preset.html#delete_preset/2"},{"type":"function","title":"Options - ExTypesense.Preset.delete_preset/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Preset.html#delete_preset/2-options"},{"type":"function","title":"Examples - ExTypesense.Preset.delete_preset/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_preset(\"listing_view\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_preset(\"listing_view\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_preset(\"listing_view\", opts)","ref":"ExTypesense.Preset.html#delete_preset/2-examples"},{"type":"function","title":"ExTypesense.Preset.get_preset/1","doc":"Retrieves all presets.","ref":"ExTypesense.Preset.html#get_preset/1"},{"type":"function","title":"ExTypesense.Preset.get_preset/2","doc":"Same as [get_preset/1](`get_preset/1`)","ref":"ExTypesense.Preset.html#get_preset/2"},{"type":"function","title":"Options - ExTypesense.Preset.get_preset/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Preset.html#get_preset/2-options"},{"type":"function","title":"Examples - ExTypesense.Preset.get_preset/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_preset(\"listing_view\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_preset(\"listing_view\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_preset(\"listing_view\", opts)","ref":"ExTypesense.Preset.html#get_preset/2-examples"},{"type":"function","title":"ExTypesense.Preset.list_presets/0","doc":"Retrieves all presets.","ref":"ExTypesense.Preset.html#list_presets/0"},{"type":"function","title":"ExTypesense.Preset.list_presets/1","doc":"Same as [list_presets/0](`list_presets/0`)","ref":"ExTypesense.Preset.html#list_presets/1"},{"type":"function","title":"Options - ExTypesense.Preset.list_presets/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Preset.html#list_presets/1-options"},{"type":"function","title":"Examples - ExTypesense.Preset.list_presets/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_presets(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_presets(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_presets(opts)","ref":"ExTypesense.Preset.html#list_presets/1-examples"},{"type":"function","title":"ExTypesense.Preset.upsert_preset/2","doc":"Create or update an existing preset.","ref":"ExTypesense.Preset.html#upsert_preset/2"},{"type":"function","title":"Examples - ExTypesense.Preset.upsert_preset/2","doc":"iex> body = %{\n    ...>   \"value\" => %{\n    ...>     \"searches\" => [\n    ...>       %{\"collection\" => \"restaurants\", \"q\" => \"*\", \"sort_by\" => \"popularity\"}\n    ...>     ]\n    ...>   }\n    ...> }\n    iex> ExTypesense.upsert_preset(\"listing_view\", body)","ref":"ExTypesense.Preset.html#upsert_preset/2-examples"},{"type":"function","title":"ExTypesense.Preset.upsert_preset/3","doc":"Same as [upsert_preset/2](`upsert_preset/2`)","ref":"ExTypesense.Preset.html#upsert_preset/3"},{"type":"function","title":"Options - ExTypesense.Preset.upsert_preset/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Preset.html#upsert_preset/3-options"},{"type":"function","title":"Examples - ExTypesense.Preset.upsert_preset/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.upsert_preset(\"listing_view\", body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.upsert_preset(\"listing_view\", body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.upsert_preset(\"listing_view\", body, opts)","ref":"ExTypesense.Preset.html#upsert_preset/3-examples"},{"type":"module","title":"ExTypesense.Search","doc":"Module for searching documents.\n\nMore here: https://typesense.org/docs/latest/api/search.html","ref":"ExTypesense.Search.html"},{"type":"function","title":"ExTypesense.Search.multi_search/1","doc":"Perform [multiple/federated](https://typesense.org/docs/latest/api/federated-multi-search.html)\nsearches at once.\nSearch params can be found [here](https://typesense.org/docs/latest/api/search.html#search-parameters).\n\n> #### Federated search {: .info}\n>\n> This is especially useful to avoid round-trip network latencies\n> incurred otherwise if each of these requests are sent in separate\n> HTTP requests.\n>\n> You can also use this feature to do a **federated search** across\n> multiple collections in a single HTTP request. For eg: in an\n> ecommerce products dataset, you can show results from both a\n> \"products\" collection, and a \"brands\" collection to the user, by\n> searching them in parallel with a multi_search request.\n\n> #### ordered results {: .tip}\n>\n> The results array in a multi_search response is guaranteed\n> to be in the same order as the queries you send in the searches\n> array in your request.","ref":"ExTypesense.Search.html#multi_search/1"},{"type":"function","title":"Options - ExTypesense.Search.multi_search/1","doc":"* `conn`: The custom connection map or struct you passed\n  * `limit_multi_searches`: Max number of search requests that can be sent in a\n  multi-search request. Default 50\n  * `x-typesense-api-key`: You can embed a separate search API key for each search\n  within a multi_search request. This is useful when you want to apply different\n  embedded filters for each collection in individual scoped API keys.\n  * `union`: When true, merges the search results from each search query into a\n  single ordered set of hits. Default `false`","ref":"ExTypesense.Search.html#multi_search/1-options"},{"type":"function","title":"Examples - ExTypesense.Search.multi_search/1","doc":"iex> searches = [\n    ...>   %{collection: \"companies\", q: \"Loca Cola\"},\n    ...>   %{collection: Company, q: \"Burgler King\"},\n    ...>   %{collection: Catalog, q: \"umbrella\"}\n    ...> ]\n    iex> ExTypesense.multi_search(searches)\n    {\n      :ok,\n      %OpenApiTypesense.MultiSearchResult{\n        results: [\n          %{\n          facet_counts: [],\n          found: 0,\n          hits: [],\n          out_of: 0,\n          page: 1,\n          request_params: %{\n            collection_name: \"companies\",\n            per_page: 10,\n            q: \"Loca Cola\",\n            first_q: \"Loca Cola\"\n          },\n          search_cutoff: false,\n          search_time_ms: 5\n          },\n          %{\n            facet_counts: [],\n            found: 0,\n            hits: [],\n            out_of: 0,\n            page: 1,\n            request_params: %{\n              collection_name: \"companies\",\n              per_page: 10,\n              q: \"Burgler King\",\n              first_q: \"Burgler King\"\n            },\n            search_cutoff: false,\n            search_time_ms: 5\n          },\n          %{\n            facet_counts: [],\n            found: 0,\n            hits: [],\n            out_of: 0,\n            page: 1,\n            request_params: %{\n              collection_name: \"catalogs\",\n              per_page: 10,\n              q: \"umbrella\",\n              first_q: \"umbrella\"\n            },\n            search_cutoff: false,\n            search_time_ms: 5\n          }\n        ],\n        conversation: nil\n      }\n    }","ref":"ExTypesense.Search.html#multi_search/1-examples"},{"type":"function","title":"ExTypesense.Search.multi_search/2","doc":"Same as [multi_search/1](`multi_search/1`)","ref":"ExTypesense.Search.html#multi_search/2"},{"type":"function","title":"Options - ExTypesense.Search.multi_search/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Search.html#multi_search/2-options"},{"type":"function","title":"Examples - ExTypesense.Search.multi_search/2","doc":"iex> opts = [conn: %{api_key: xyz, host: ...}, ...]\n    iex> ExTypesense.multi_search(searches, opts)\n\n    iex> opts = [conn: OpenApiTypesense.Connection.new(), ...]\n    iex> ExTypesense.multi_search(searches, opts)","ref":"ExTypesense.Search.html#multi_search/2-examples"},{"type":"function","title":"ExTypesense.Search.multi_search_ecto/1","doc":"Same as [multi_search/1](`multi_search/1`) but returns a list of Ecto queries.","ref":"ExTypesense.Search.html#multi_search_ecto/1"},{"type":"function","title":"Options (same as multi_search/1) - ExTypesense.Search.multi_search_ecto/1","doc":"* `limit_multi_searches`: Max number of search requests that can be sent in a\n  multi-search request. Default 50\n  * `x-typesense-api-key`: You can embed a separate search API key for each search\n  within a multi_search request. This is useful when you want to apply different\n  embedded filters for each collection in individual scoped API keys.","ref":"ExTypesense.Search.html#multi_search_ecto/1-options-same-as-multi_search-1"},{"type":"function","title":"Examples - ExTypesense.Search.multi_search_ecto/1","doc":"iex> # Do note the collection name isn't string!!!\n    iex> searches = [\n    ...>   %{collection: Company, q: \"Burgler King\"},\n    ...>   %{collection: Catalog, q: \"spoon\"}\n    ...> ]\n    iex> ExTypesense.multi_search_ecto(searches)","ref":"ExTypesense.Search.html#multi_search_ecto/1-examples"},{"type":"function","title":"ExTypesense.Search.multi_search_ecto/2","doc":"Same as [multi_search_ecto/1](`multi_search_ecto/1`)","ref":"ExTypesense.Search.html#multi_search_ecto/2"},{"type":"function","title":"Options - ExTypesense.Search.multi_search_ecto/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Search.html#multi_search_ecto/2-options"},{"type":"function","title":"Examples - ExTypesense.Search.multi_search_ecto/2","doc":"iex> opts = [conn: %{api_key: xyz, host: ...}, ...]\n    iex> ExTypesense.multi_search_ecto(searches, opts)\n\n    iex> opts = [conn: OpenApiTypesense.Connection.new(), ...]\n    iex> ExTypesense.multi_search_ecto(searches, opts)","ref":"ExTypesense.Search.html#multi_search_ecto/2-examples"},{"type":"function","title":"ExTypesense.Search.search/2","doc":"Search from a document or Ecto Schema.","ref":"ExTypesense.Search.html#search/2"},{"type":"function","title":"Options - ExTypesense.Search.search/2","doc":"* `conn`: The custom connection map or struct you passed\n  * Search params can be found [here](https://typesense.org/docs/latest/api/search.html#search-parameters).","ref":"ExTypesense.Search.html#search/2-options"},{"type":"function","title":"Examples - ExTypesense.Search.search/2","doc":"iex> params = [q: \"umbrella\", query_by: \"title,description\"]\n    iex> ExTypesense.search(Catalog, params)\n    {:ok,\n     %OpenApiTypesense.SearchResult{\n      found: 0,\n      hits: [],\n      conversation: nil,\n      facet_counts: [],\n      found_docs: nil,\n      grouped_hits: nil,\n      out_of: 0,\n      page: 1,\n      request_params: %{\n        q: \"umbrella\",\n        collection_name: \"catalogs\",\n        first_q: \"umbrella\",\n        per_page: 10\n      },\n      search_cutoff: false,\n      search_time_ms: 1\n     }\n    }\n\n    iex> params = %{q: \"umbrella\", query_by: \"title,description\"}\n    iex> ExTypesense.search(\"catalogs\", params)\n    {:ok,\n     %OpenApiTypesense.SearchResult{\n      found: 0,\n      hits: [],\n      conversation: nil,\n      facet_counts: [],\n      found_docs: nil,\n      grouped_hits: nil,\n      out_of: 0,\n      page: 1,\n      request_params: %{\n        q: \"umbrella\",\n        collection_name: \"catalogs\",\n        first_q: \"umbrella\",\n        per_page: 10\n      },\n      search_cutoff: false,\n      search_time_ms: 1\n     }\n    }\n\n    iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.search(\"companies\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.search(\"companies\", conn: conn)\n\n    iex> opts = [conn: conn, q: \"hat\", ...]\n    iex> ExTypesense.search(\"companies\", opts)","ref":"ExTypesense.Search.html#search/2-examples"},{"type":"function","title":"ExTypesense.Search.search_ecto/2","doc":"Same as [search/2](`search/2`) but matches Ecto record(s) and returns struct(s).","ref":"ExTypesense.Search.html#search_ecto/2"},{"type":"function","title":"Options - ExTypesense.Search.search_ecto/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Search.html#search_ecto/2-options"},{"type":"function","title":"Examples - ExTypesense.Search.search_ecto/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.search_ecto(\"companies\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.search_ecto(\"companies\", conn: conn)\n\n    iex> opts = [conn: conn, ...]\n    iex> ExTypesense.search_ecto(\"companies\", opts)","ref":"ExTypesense.Search.html#search_ecto/2-examples"},{"type":"module","title":"ExTypesense.Stemming","doc":"Stemming specific operations.\n\nMore here: https://typesense.org/docs/latest/api/stemming.html","ref":"ExTypesense.Stemming.html"},{"type":"function","title":"ExTypesense.Stemming.get_stemming_dictionary/1","doc":"Retrieve a stemming dictionary\n\nFetch details of a specific stemming dictionary.","ref":"ExTypesense.Stemming.html#get_stemming_dictionary/1"},{"type":"function","title":"ExTypesense.Stemming.get_stemming_dictionary/2","doc":"Same as [get_stemming_dictionary/1](`get_stemming_dictionary/1`)","ref":"ExTypesense.Stemming.html#get_stemming_dictionary/2"},{"type":"function","title":"Options - ExTypesense.Stemming.get_stemming_dictionary/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Stemming.html#get_stemming_dictionary/2-options"},{"type":"function","title":"Examples - ExTypesense.Stemming.get_stemming_dictionary/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_stemming_dictionary(dictionary_id, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_stemming_dictionary(dictionary_id, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_stemming_dictionary(dictionary_id, opts)","ref":"ExTypesense.Stemming.html#get_stemming_dictionary/2-examples"},{"type":"function","title":"ExTypesense.Stemming.import_stemming_dictionary/2","doc":"Import a stemming dictionary","ref":"ExTypesense.Stemming.html#import_stemming_dictionary/2"},{"type":"function","title":"Options - ExTypesense.Stemming.import_stemming_dictionary/2","doc":"* `conn`: The custom connection map or struct you passed\n  * `id`: The ID to assign to the dictionary","ref":"ExTypesense.Stemming.html#import_stemming_dictionary/2-options"},{"type":"function","title":"Example - ExTypesense.Stemming.import_stemming_dictionary/2","doc":"iex> body = [\n    ...>   %{\"word\" => \"people\", \"root\" => \"person\"}\n    ...>   %{\"word\" => \"children\", \"root\" => \"child\"}\n    ...>   %{\"word\" => \"geese\", \"root\" => \"goose\"}\n    ...> ]\n    iex> ExTypesense.import_stemming_dictionary(body, id: \"irregular-plurals\")\n\n    iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.import_stemming_dictionary(body, id: \"irregular-plurals\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.import_stemming_dictionary(body, id: \"irregular-plurals\", conn: conn)\n\n    iex> opts = [id: \"irregular-plurals\", conn: conn]\n    iex> ExTypesense.import_stemming_dictionary(body, opts)","ref":"ExTypesense.Stemming.html#import_stemming_dictionary/2-example"},{"type":"function","title":"ExTypesense.Stemming.list_stemming_dictionaries/0","doc":"List all stemming dictionaries","ref":"ExTypesense.Stemming.html#list_stemming_dictionaries/0"},{"type":"function","title":"ExTypesense.Stemming.list_stemming_dictionaries/1","doc":"Same as [list_stemming_dictionaries/0](`list_stemming_dictionaries/0`)","ref":"ExTypesense.Stemming.html#list_stemming_dictionaries/1"},{"type":"function","title":"Options - ExTypesense.Stemming.list_stemming_dictionaries/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Stemming.html#list_stemming_dictionaries/1-options"},{"type":"function","title":"Examples - ExTypesense.Stemming.list_stemming_dictionaries/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_stemming_dictionaries(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_stemming_dictionaries(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_stemming_dictionaries(opts)","ref":"ExTypesense.Stemming.html#list_stemming_dictionaries/1-examples"},{"type":"module","title":"ExTypesense.Stopwords","doc":"Stopwords are keywords which will be removed from search\nquery while searching.\n\n> #### During indexing {: .info}\n>\n> Stopwords are **NOT** dropped during indexing.\n\nMore here: https://typesense.org/docs/latest/api/stopwords.html","ref":"ExTypesense.Stopwords.html"},{"type":"function","title":"ExTypesense.Stopwords.delete_stopword/1","doc":"Permanently deletes a stopwords set, given it's name.","ref":"ExTypesense.Stopwords.html#delete_stopword/1"},{"type":"function","title":"ExTypesense.Stopwords.delete_stopword/2","doc":"Same as [delete_stopword/1](`delete_stopword/1`)","ref":"ExTypesense.Stopwords.html#delete_stopword/2"},{"type":"function","title":"Options - ExTypesense.Stopwords.delete_stopword/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Stopwords.html#delete_stopword/2-options"},{"type":"function","title":"Examples - ExTypesense.Stopwords.delete_stopword/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_stopword(\"stopword_set_countries\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_stopword(\"stopword_set_countries\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_stopword(\"stopword_set_countries\", opts)","ref":"ExTypesense.Stopwords.html#delete_stopword/2-examples"},{"type":"function","title":"ExTypesense.Stopwords.get_stopword/1","doc":"Retrieve the details of a stopwords set, given it's name.","ref":"ExTypesense.Stopwords.html#get_stopword/1"},{"type":"function","title":"ExTypesense.Stopwords.get_stopword/2","doc":"Same as [get_stopword/1](`get_stopword/1`)","ref":"ExTypesense.Stopwords.html#get_stopword/2"},{"type":"function","title":"Options - ExTypesense.Stopwords.get_stopword/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Stopwords.html#get_stopword/2-options"},{"type":"function","title":"Examples - ExTypesense.Stopwords.get_stopword/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_stopword(\"stopword_set_countries\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_stopword(\"stopword_set_countries\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_stopword(\"stopword_set_countries\", opts)","ref":"ExTypesense.Stopwords.html#get_stopword/2-examples"},{"type":"function","title":"ExTypesense.Stopwords.list_stopwords/0","doc":"Retrieves all stopwords sets.","ref":"ExTypesense.Stopwords.html#list_stopwords/0"},{"type":"function","title":"ExTypesense.Stopwords.list_stopwords/1","doc":"Same as [list_stopwords/0](`list_stopwords/0`)","ref":"ExTypesense.Stopwords.html#list_stopwords/1"},{"type":"function","title":"Options - ExTypesense.Stopwords.list_stopwords/1","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Stopwords.html#list_stopwords/1-options"},{"type":"function","title":"Examples - ExTypesense.Stopwords.list_stopwords/1","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_stopwords(conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_stopwords(conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_stopwords(opts)","ref":"ExTypesense.Stopwords.html#list_stopwords/1-examples"},{"type":"function","title":"ExTypesense.Stopwords.upsert_stopword/2","doc":"Upserts a stopwords set.","ref":"ExTypesense.Stopwords.html#upsert_stopword/2"},{"type":"function","title":"Examples - ExTypesense.Stopwords.upsert_stopword/2","doc":"iex> body = %{\n    ...>   \"stopwords\" => [\n    ...>     \"Bustin Jieber\",\n    ...>     \"Pelvis Presly\",\n    ...>     \"Tinus Lorvalds\",\n    ...>     \"Britney Smears\"\n    ...>   ],\n    ...>   \"locale\" => \"en\"\n    ...> }\n    iex> ExTypesense.upsert_override(\"stopwords-famous-person\", body)","ref":"ExTypesense.Stopwords.html#upsert_stopword/2-examples"},{"type":"function","title":"ExTypesense.Stopwords.upsert_stopword/3","doc":"Same as [upsert_stopword/2](`upsert_stopword/2`)","ref":"ExTypesense.Stopwords.html#upsert_stopword/3"},{"type":"function","title":"Options - ExTypesense.Stopwords.upsert_stopword/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Stopwords.html#upsert_stopword/3-options"},{"type":"function","title":"Examples - ExTypesense.Stopwords.upsert_stopword/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.upsert_stopword(\"stopword_set_countries\", body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.upsert_stopword(\"stopword_set_countries\", body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.upsert_stopword(\"stopword_set_countries\", body, opts)","ref":"ExTypesense.Stopwords.html#upsert_stopword/3-examples"},{"type":"module","title":"ExTypesense.Synonym","doc":"The synonyms feature allows you to define search terms that should\nbe considered equivalent. For eg: when you define a synonym for\n`sneaker` as `shoe`, searching for `sneaker` will now return all records\nwith the word `shoe` in them, in addition to records with the word `sneaker`.\n\nMore here: https://typesense.org/docs/latest/api/synonyms.html","ref":"ExTypesense.Synonym.html"},{"type":"function","title":"ExTypesense.Synonym.delete_synonym/2","doc":"Delete a single synonym from a collection.","ref":"ExTypesense.Synonym.html#delete_synonym/2"},{"type":"function","title":"ExTypesense.Synonym.delete_synonym/3","doc":"Same as [delete_synonym/2](`delete_synonym/2`).","ref":"ExTypesense.Synonym.html#delete_synonym/3"},{"type":"function","title":"Options - ExTypesense.Synonym.delete_synonym/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Synonym.html#delete_synonym/3-options"},{"type":"function","title":"Examples - ExTypesense.Synonym.delete_synonym/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.delete_synonym(\"cars\", \"sedan-synonym\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.delete_synonym(\"cars\", \"sedan-synonym\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.delete_synonym(MyApp.Vehicle.Car, \"sedan-synonym\", opts)","ref":"ExTypesense.Synonym.html#delete_synonym/3-examples"},{"type":"function","title":"ExTypesense.Synonym.get_synonym/2","doc":"Retrieve a single synonym from a collection.","ref":"ExTypesense.Synonym.html#get_synonym/2"},{"type":"function","title":"ExTypesense.Synonym.get_synonym/3","doc":"Same as [get_synonym/2](`get_synonym/2`).","ref":"ExTypesense.Synonym.html#get_synonym/3"},{"type":"function","title":"Options - ExTypesense.Synonym.get_synonym/3","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Synonym.html#get_synonym/3-options"},{"type":"function","title":"Examples - ExTypesense.Synonym.get_synonym/3","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.get_synonym(\"cars\", \"sedan-synonym\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.get_synonym(\"cars\", \"sedan-synonym\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.get_synonym(MyApp.Vehicle.Car, \"sedan-synonym\", opts)","ref":"ExTypesense.Synonym.html#get_synonym/3-examples"},{"type":"function","title":"ExTypesense.Synonym.list_synonyms/1","doc":"List all synonyms associated with a given collection.\n\n> #### Error {: .info}\n>\n> By default, **ALL** synonyms are returned, but you can use the\n> `offset` and `limit` parameters to paginate on the listing.","ref":"ExTypesense.Synonym.html#list_synonyms/1"},{"type":"function","title":"Options - ExTypesense.Synonym.list_synonyms/1","doc":"* `limit`: Limit results in paginating on collection listing.\n  * `offset`: Skip a certain number of results and start after that.","ref":"ExTypesense.Synonym.html#list_synonyms/1-options"},{"type":"function","title":"ExTypesense.Synonym.list_synonyms/2","doc":"Same as [list_synonyms/1](`list_synonyms/1`).","ref":"ExTypesense.Synonym.html#list_synonyms/2"},{"type":"function","title":"Options - ExTypesense.Synonym.list_synonyms/2","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Synonym.html#list_synonyms/2-options"},{"type":"function","title":"Examples - ExTypesense.Synonym.list_synonyms/2","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.list_synonyms(\"persons\", conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.list_synonyms(\"persons\", conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.list_synonyms(MyApp.Accounts.Person, opts)","ref":"ExTypesense.Synonym.html#list_synonyms/2-examples"},{"type":"function","title":"ExTypesense.Synonym.upsert_synonym/3","doc":"Create or update a synonym","ref":"ExTypesense.Synonym.html#upsert_synonym/3"},{"type":"function","title":"Examples - ExTypesense.Synonym.upsert_synonym/3","doc":"iex> body = %{\n    ...>   \"synonyms\" => [\"blazer\", \"coat\", \"jacket\"],\n    ...> }\n\n    iex> ExTypesense.upsert_synonym(\"products\", \"coat-synonyms\", body)","ref":"ExTypesense.Synonym.html#upsert_synonym/3-examples"},{"type":"function","title":"ExTypesense.Synonym.upsert_synonym/4","doc":"Same as [upsert_synonym/3](`upsert_synonym/3`).","ref":"ExTypesense.Synonym.html#upsert_synonym/4"},{"type":"function","title":"Options - ExTypesense.Synonym.upsert_synonym/4","doc":"* `conn`: The custom connection map or struct you passed","ref":"ExTypesense.Synonym.html#upsert_synonym/4-options"},{"type":"function","title":"Examples - ExTypesense.Synonym.upsert_synonym/4","doc":"iex> conn = %{api_key: xyz, host: ...}\n    iex> ExTypesense.upsert_synonym(\"persons\", \"coat-synonyms\", body, conn: conn)\n\n    iex> conn = OpenApiTypesense.Connection.new()\n    iex> ExTypesense.upsert_synonym(\"persons\", \"coat-synonyms\", body, conn: conn)\n\n    iex> opts = [conn: conn]\n    iex> ExTypesense.upsert_synonym(MyApp.Accounts.Person, \"coat-synonyms\", body, opts)","ref":"ExTypesense.Synonym.html#upsert_synonym/4-examples"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).","ref":"changelog.html"},{"type":"extras","title":"major.minor.patch (yyyy.mm.dd) - Changelog","doc":"","ref":"changelog.html#major-minor-patch-yyyy-mm-dd"},{"type":"extras","title":"2.0.1 (2025.06.18) - Changelog","doc":"","ref":"changelog.html#2-0-1-2025-06-18"},{"type":"extras","title":"Fixed - Changelog","doc":"* Dialyzer issues, inconsistent return types [Issue #80](https://github.com/jaeyson/ex_typesense/issues/80) [PR #84](https://github.com/jaeyson/ex_typesense/pull/84).","ref":"changelog.html#fixed"},{"type":"extras","title":"2.0.0 (2025.06.01) - Changelog","doc":"","ref":"changelog.html#2-0-0-2025-06-01"},{"type":"extras","title":"Changed - Changelog","doc":"* Passing `conn` as part of `opts` when calling a function, as this reduces code duplication. [PR #82](https://github.com/jaeyson/ex_typesense/pull/82)","ref":"changelog.html#changed"},{"type":"extras","title":"Chore - Changelog","doc":"* Bumped dev dependencies","ref":"changelog.html#chore"},{"type":"extras","title":"1.2.1 (2025.05.11) - Changelog","doc":"","ref":"changelog.html#1-2-1-2025-05-11"},{"type":"extras","title":"Fixed - Changelog","doc":"* Remove `collection_name` field in return value when indexing or updating a document via map. [Issue #77](https://github.com/jaeyson/ex_typesense/issues/77) [PR #78](https://github.com/jaeyson/ex_typesense/pull/78)","ref":"changelog.html#fixed-1"},{"type":"extras","title":"1.2.0 (2025.04.06) - Changelog","doc":"","ref":"changelog.html#1-2-0-2025-04-06"},{"type":"extras","title":"Added - Changelog","doc":"* `Stemming` module\n* Tests for new module\n* `ExTypesense.get_schema_changes`","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"* Pass [`union`](https://typesense.org/docs/28.0/api/federated-multi-search.html#union-search) key on multi search\n* Bump dependency version.","ref":"changelog.html#changed-1"},{"type":"extras","title":"Removed - Changelog","doc":"* `ExTypesense.get_collection_name`, use `ExTypesense.get_collection_alias`","ref":"changelog.html#removed"},{"type":"extras","title":"1.1.1 (2025.03.26) - Changelog","doc":"","ref":"changelog.html#1-1-1-2025-03-26"},{"type":"extras","title":"Changed - Changelog","doc":"* Bump dependency version.","ref":"changelog.html#changed-2"},{"type":"extras","title":"1.1.0 (2025.03.02) - Changelog","doc":"","ref":"changelog.html#1-1-0-2025-03-02"},{"type":"extras","title":"Added - Changelog","doc":"* `Collection.create_collection_with_alias/1`.\n* Allow module name (atom) to be passed as alias name in `Collection.create_collection_with_alias/1`.\n* Typespec to pass also omodule name (atom) for `Collection.create_collection_with_alias/1`.\n* Separate dev and test environments.","ref":"changelog.html#added-1"},{"type":"extras","title":"Fixed - Changelog","doc":"* Typespecs for `Search.multi_search_ecto`.\n* Return values of `Search.multi_search_ecto` for `search_test.exs`.","ref":"changelog.html#fixed-2"},{"type":"extras","title":"Deprecated - Changelog","doc":"* `Collection.get_collection_name/1`","ref":"changelog.html#deprecated"},{"type":"extras","title":"1.0.2 (2025.01.30) - Changelog","doc":"","ref":"changelog.html#1-0-2-2025-01-30"},{"type":"extras","title":"Changed - Changelog","doc":"* Bump dependency version.","ref":"changelog.html#changed-3"},{"type":"extras","title":"1.0.1 (2025.01.26) - Changelog","doc":"","ref":"changelog.html#1-0-1-2025-01-26"},{"type":"extras","title":"Changed - Changelog","doc":"* Bump dependency version.\n* README banner image","ref":"changelog.html#changed-4"},{"type":"extras","title":"1.0.0 (2025.01.19) - Changelog","doc":"","ref":"changelog.html#1-0-0-2025-01-19"},{"type":"extras","title":"Added - Changelog","doc":"* External docs link for example of using another HTTP client.\n* More test coverage","ref":"changelog.html#added-2"},{"type":"extras","title":"Changed - Changelog","doc":"* Backwards-incompatible changes, in favor of using [`OpenApiTypesense`](https://github.com/jaeyson/open_api_typesense).\n* Bump dependencies\n* CI to support Typesense versions v26.0, v27.0, v27.1","ref":"changelog.html#changed-5"},{"type":"extras","title":"Removed - Changelog","doc":"* Dropped support for Typesense version v0.25.2\n* `ExTypesense.ResultParser` module (moved to `ExTypesense.Search`)","ref":"changelog.html#removed-1"},{"type":"extras","title":"Deprecated - Changelog","doc":"* Dropped support for Typesense v0.25.2","ref":"changelog.html#deprecated-1"},{"type":"extras","title":"0.7.3 (2024.11.11) - Changelog","doc":"","ref":"changelog.html#0-7-3-2024-11-11"},{"type":"extras","title":"Added - Changelog","doc":"* `{:error, String.t()}` type for `Search.search/3`","ref":"changelog.html#added-3"},{"type":"extras","title":"0.7.2 (2024.11.07) - Changelog","doc":"","ref":"changelog.html#0-7-2-2024-11-07"},{"type":"extras","title":"Changed - Changelog","doc":"* Use `v27.1` of [Typesense](https://typesense.org/docs/27.1/api) in CI and local development.","ref":"changelog.html#changed-6"},{"type":"extras","title":"0.7.1 (2024.09.10) - Changelog","doc":"","ref":"changelog.html#0-7-1-2024-09-10"},{"type":"extras","title":"Removed - Changelog","doc":"* `:castore` dependency not passing on CI test","ref":"changelog.html#removed-2"},{"type":"extras","title":"0.7.0 (2024.09.10) - Changelog","doc":"","ref":"changelog.html#0-7-0-2024-09-10"},{"type":"extras","title":"Changed - Changelog","doc":"* HTTP request construction in `ExTypesense.HttpClient` to include `options`.\n* Bumped dependencies","ref":"changelog.html#changed-7"},{"type":"extras","title":"Added - Changelog","doc":"* `options` in config `config/config.exs`.\n* `get_options/0` function in `HttpClient` to fetch the `options` configuration.\n* tests for `get_options/0` in `ExTypesense.HttpClientTest`.","ref":"changelog.html#added-4"},{"type":"extras","title":"0.6.0 (2024.07.15) - Changelog","doc":"","ref":"changelog.html#0-6-0-2024-07-15"},{"type":"extras","title":"Changed - Changelog","doc":"* Move application env variables from `test_helper.exs` to `config` directory, in usage for both `dev` and `test` environments.","ref":"changelog.html#changed-8"},{"type":"extras","title":"Added - Changelog","doc":"* Function: [multi search](https://typesense.org/docs/26.0/api/federated-multi-search.html)","ref":"changelog.html#added-5"},{"type":"extras","title":"0.5.0 (2024.07.13) - Changelog","doc":"","ref":"changelog.html#0-5-0-2024-07-13"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` regarding `default_sorting_field`, where it joins the table name with `_id` (e.g. `images` is `images_id` instead of `image_id`).","ref":"changelog.html#changed-9"},{"type":"extras","title":"Added - Changelog","doc":"* Function: [delete by query](https://typesense.org/docs/26.0/api/documents.html#delete-by-query).\n* Function: [delete all documents](https://github.com/typesense/typesense/issues/1613#issuecomment-1994986258) in a collection.\n* Collection's schema [field parameters](https://typesense.org/docs/26.0/api/collections.html#field-parameters):\n  - `:vec_dist`\n  - `:store`\n  - `:reference`\n  - `:range_index`\n  - `:stem`","ref":"changelog.html#added-6"},{"type":"extras","title":"Removed - Changelog","doc":"- `HttpClient.run` and `HttpClient.httpc_run` function (use `HttpClient.request`).","ref":"changelog.html#removed-3"},{"type":"extras","title":"0.4.3 (2024.07.03) - Changelog","doc":"","ref":"changelog.html#0-4-3-2024-07-03"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` regarding test and connection strings.\n* Replacing connection struct to map.","ref":"changelog.html#changed-10"},{"type":"extras","title":"0.4.2 (2024.06.19) - Changelog","doc":"","ref":"changelog.html#0-4-2-2024-06-19"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` and cheatsheet details regarding on setup for creation of collection schema.","ref":"changelog.html#changed-11"},{"type":"extras","title":"0.4.1 (2024.06.11) - Changelog","doc":"","ref":"changelog.html#0-4-1-2024-06-11"},{"type":"extras","title":"Changed - Changelog","doc":"* `README` on running `docker compose`.","ref":"changelog.html#changed-12"},{"type":"extras","title":"0.4.0 (2024.05.20) - Changelog","doc":"","ref":"changelog.html#0-4-0-2024-05-20"},{"type":"extras","title":"Added - Changelog","doc":"* Connection module for dynamic loading of credentials.\n* Default connection config when running commands (e.g. create collections, etc.).","ref":"changelog.html#added-7"},{"type":"extras","title":"Changed - Changelog","doc":"* Refactor `ExTypesense.HttpClient` on how to handle request.\n* Bumped dependencies' version.\n* Dropped usage of `:httpc` in favor of using [`Req library`](https://hex.pm/packages/req).","ref":"changelog.html#changed-13"},{"type":"extras","title":"Deprecated - Changelog","doc":"* Some functions from `Document` and `HttpClient` where soft depcrated in order to incorporate the `Connection` module for dynamic connections loaded from Ecto schema. If you read the docs, you might notice it's marked with `deprecated` and encourages to use the newer ones.","ref":"changelog.html#deprecated-2"},{"type":"extras","title":"0.3.5 (2023.08.13) - Changelog","doc":"","ref":"changelog.html#0-3-5-2023-08-13"},{"type":"extras","title":"Fixed - Changelog","doc":"* Fixed typos","ref":"changelog.html#fixed-3"},{"type":"extras","title":"0.3.4 (2023.07.12) - Changelog","doc":"","ref":"changelog.html#0-3-4-2023-07-12"},{"type":"extras","title":"Changed - Changelog","doc":"* Remove string conversion on struct id when deleting a document.","ref":"changelog.html#changed-14"},{"type":"extras","title":"0.3.3 (2023.07.11) - Changelog","doc":"","ref":"changelog.html#0-3-3-2023-07-11"},{"type":"extras","title":"Added - Changelog","doc":"* Add index_multiple_documents/1 clause for accepting struct args.","ref":"changelog.html#added-8"},{"type":"extras","title":"0.3.2 (2023.07.11) - Changelog","doc":"","ref":"changelog.html#0-3-2-2023-07-11"},{"type":"extras","title":"Changed - Changelog","doc":"* Maps struct pk to document's id.\n* Update http request timeout to `3,600` seconds.","ref":"changelog.html#changed-15"},{"type":"extras","title":"0.3.1 (2023.07.11) - Changelog","doc":"","ref":"changelog.html#0-3-1-2023-07-11"},{"type":"extras","title":"Changed - Changelog","doc":"* Increase connection timeout.","ref":"changelog.html#changed-16"},{"type":"extras","title":"0.3.0 (2023.06.20) - Changelog","doc":"","ref":"changelog.html#0-3-0-2023-06-20"},{"type":"extras","title":"Fixed - Changelog","doc":"* Fixed url request path for aliases.","ref":"changelog.html#fixed-4"},{"type":"extras","title":"Changed - Changelog","doc":"* Refactor functions inside collection and document.\n* Changed return values from `{:ok, t()}` to `t()` only.\n* Parse schema field types for `float`, `boolean`, `string`, `integer` and a list with these corresponding types.","ref":"changelog.html#changed-17"},{"type":"extras","title":"Added - Changelog","doc":"* Added cheatsheet section on docs.","ref":"changelog.html#added-9"},{"type":"extras","title":"0.2.2 (2023.01.26) - Changelog","doc":"","ref":"changelog.html#0-2-2-2023-01-26"},{"type":"extras","title":"Changed - Changelog","doc":"* Updated docs","ref":"changelog.html#changed-18"},{"type":"extras","title":"0.2.1 (2023.01.22) - Changelog","doc":"","ref":"changelog.html#0-2-1-2023-01-22"},{"type":"extras","title":"Changed - Changelog","doc":"* Returned an ecto query instead of list of results.","ref":"changelog.html#changed-19"},{"type":"extras","title":"0.2.0 (2023.01.20) - Changelog","doc":"","ref":"changelog.html#0-2-0-2023-01-20"},{"type":"extras","title":"Added - Changelog","doc":"* Added search function which returns a list of structs or empty.","ref":"changelog.html#added-10"},{"type":"extras","title":"0.1.0 (2023.01.20) - Changelog","doc":"* Initial release","ref":"changelog.html#0-1-0-2023-01-20"},{"type":"extras","title":"ExTypesense","doc":"# ExTypesense\n\n \n   \n   \n   \n   \n \n\n \n   \n     \n   \n   \n     \n   \n   \n     \n   \n   \n     \n   \n   \n     \n   \n \n\n \n   \n     \n   \n   \n     \n   \n   \n     \n   \n   \n     \n   \n \n\n[Typesense](https://typesense.org) client for [Elixir](https://elixir-lang.org) with support for your Ecto schemas.\n\n> #### OpenAPI adherence {: .tip}\n>\n> Under the hood, this library utilizes [open_api_typesense](https://github.com/jaeyson/open_api_typesense)\n> to make sure it adheres to [Typesense's OpenAPI spec](https://github.com/typesense/typesense-api-spec).\n\n> #### Upgrading to v2 {: .warning}\n>\n> Purpose of v2 is to reduce code duplication (from v1) and to streamline\n> passing of options (including `conn`). The breaking change here\n> is that `conn` is now part of `opts`. > when calling functions, see\n> example below:\n\n```elixir\n# pre-v2\nExTypesense.list_collections(conn, opts)\n\n# v2\nExTypesense.list_collections(conn: conn)\n\n# another way (v2)\nopts = [limit: 1, conn: conn]\nExTypesense.list_collections(opts)\n```","ref":"readme.html"},{"type":"extras","title":"Installation - ExTypesense","doc":"ExTypesense requires Elixir `~> 1.14.x`. Read the [Changelog](CHANGELOG.md) for all available\nreleases and requirements. This library is published to both [Hex.pm](https://hex.pm/ex_typesense)\nand [GitHub ](https://github.com/jaeyson/ex_typesense.git) repository.\n\nAdd `:ex_typesense` to your list of dependencies in the Elixir project config file, `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    # From default Hex package manager\n    {:ex_typesense, \"~> 2.0\"}\n\n    # Or from GitHub repository, if you want the latest greatest from main branch\n    {:ex_typesense, git: \"https://github.com/jaeyson/ex_typesense.git\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Getting started - ExTypesense","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"0. (Optional) Run local Typesense instance - ExTypesense","doc":"If you want to try this library locally:\n\n```bash\ndocker compose up -d\n```\n\nMore info on spinning a local instance: https://typesense.org/docs/guide/install-typesense.html\n\nOtherwise, go to step #1 if you're using [Cloud hosted](https://cloud.typesense.org) instance instead.","ref":"readme.html#0-optional-run-local-typesense-instance"},{"type":"extras","title":"1. Add credential to config - ExTypesense","doc":"After you have setup a [local](./guides/running_local_typesense.md) Typesense or\n[Cloud hosted](https://cloud.typesense.org) instance, there are 2 ways to set the credentials:\n\n<!-- tabs-open -->","ref":"readme.html#1-add-credential-to-config"},{"type":"extras","title":"using config - ExTypesense","doc":"Option 1: Set credentials via config (e.g. `config/runtime.exs`)\n\n```elixir\n# e.g. config/runtime.exs\nif config_env() == :prod do # if you'll use this in prod environment\n  config :open_api_typesense,\n    api_key: \"xyz\",\n    host: \"localhost\",\n    port: 8108,\n    scheme: \"http\"\n  ...\n```\n\n> #### `options` key {: .tip}\n>\n> The `options` key can be used to pass additional configuration\n> options such as custom Finch instance or receive timeout\n> settings. You can add any options supported by Req here. For\n> more details check [Req documentation](https://hexdocs.pm/req/Req.Steps.html#run_finch/1-request-options).\n\n> #### during tests {: .tip}\n>\n> If you have a different config for your app, consider \n> adding it in `config/test.exs`.\n\nFor Cloud hosted, you can generate and obtain the credentials from cluster instance admin interface:\n\n```elixir\nconfig :open_api_typesense,\n  api_key: \"credential\", # Admin API key\n  host: \"111222333aaabbbcc-9.x9.typesense.net\", # Nodes\n  port: 443,\n  scheme: \"https\"\n```\n\nTest if working:\n\n```elixir\nExTypesense.health()\n```","ref":"readme.html#using-config"},{"type":"extras","title":"using map - ExTypesense","doc":"Option 2: Set credentials from a map\n\n> #### optional `conn` {: .tip}\n>\n> By default you don't need to pass connections every\n> time you use a function, if you use \"Option 1\" above.\n\nYou may have a `Connection` Ecto schema in your app and want to pass your own creds dynamically:\n\n```elixir\ndefmodule MyApp.Credential do\n  schema \"credentials\" do\n    field :node, :string\n    field :secret_key, :string\n    field :port, :integer\n  end\nend\n```\n\nAs long as the keys matches in [`OpenApiTypesense.Connection.t()`](https://hexdocs.pm/open_api_typesense/OpenApiTypesense.Connection.html#t:t/0):\n\n```elixir\ncredential = MyApp.Credential |> where(id: ^8888) |> Repo.one()\n\nconn = %{\n  host: credential.node,\n  api_key: credential.secret_key,\n  port: credential.port,\n  scheme: \"https\"\n}\n\n# NOTE: create a collection and import documents\n# first before using the command below\nExTypesense.search(collection_name, query, conn: conn)\n```\n\nOr convert your struct to map, as long as the keys matches in [`OpenApiTypesense.Connection.t()`](https://hexdocs.pm/open_api_typesense/OpenApiTypesense.Connection.html#t:t/0):\n\n```elixir\nconn = Map.from_struct(MyApp.Credential)\n\n# NOTE: create a collection and import documents\n# first before using the command below\nExTypesense.search(collection_name, query, conn: conn)\n```\n\nOr you don't want to change the fields in your Ecto schema, thus you convert it to map:\n\n```elixir\nconn = %Credential{\n  node: \"localhost\",\n  secret_key: \"xyz\",\n  port: 8108,\n  scheme: \"http\"\n}\n\nconn =\n  conn\n  |> Map.from_struct()\n  |> Map.drop([:node, :secret_key])\n  |> Map.put(:host, conn.node)\n  |> Map.put(:api_key, conn.secret_key)\n\n# NOTE: create a collection and import documents\n# first before using the command below\nExTypesense.search(collection_name, query, conn: conn)\n```\n\nOr just plain map\n\n```elixir\nconn = %{\n    host: \"127.0.0.1\",\n    api_key: \"xyz\",\n    port: 8108,\n    scheme: \"http\"\n}\n\nExTypesense.health(conn: conn)\n```\n\n<!-- tabs-close -->","ref":"readme.html#using-map"},{"type":"extras","title":"2. Create a collection - ExTypesense","doc":"There are 2 ways to create a collection, either via\n[Ecto schema](https://hexdocs.pm/ecto/Ecto.Schema.html) or using map\n([an Elixir data type](https://hexdocs.pm/elixir/keywords-and-maps.html#maps-as-key-value-pairs)):\n\n<!-- tabs-open -->","ref":"readme.html#2-create-a-collection"},{"type":"extras","title":"using Ecto schema - ExTypesense","doc":"> #### added fk in schema {: .info}\n>\n> The format we're using is ` _id`. If you have table e.g. named `persons`,\n> it'll be `persons_id`.\n>\n> `persons_id` is of type `integer`: read the discussion on why\n> we need to add [default_sorting_field](https://github.com/typesense/typesense/issues/72#issuecomment-645725013).\n\n```elixir\ndefmodule Person do\n  use Ecto.Schema\n  @behaviour ExTypesense\n\n  # In this example, we're adding `persons_id`\n  # that points to the id of `persons` schema.\n\n  defimpl Jason.Encoder, for: __MODULE__ do\n    def encode(value, opts) do\n      value\n      |> Map.take([:id, :persons_id, :name, :country])\n      |> Enum.map(fn {key, val} ->\n        cond do\n          key === :id -> {key, to_string(Map.get(value, :id))}\n          key === :persons_id -> {key, Map.get(value, :id)}\n          true -> {key, val}\n        end\n      end)\n      |> Enum.into(%{})\n      |> Jason.Encode.map(opts)\n    end\n  end\n\n  schema \"persons\" do\n    field(:name, :string)\n    field(:country, :string)\n    field(:persons_id, :integer, virtual: true)\n  end\n\n  @impl ExTypesense\n  def get_field_types do\n      name = __MODULE__.__schema__(:source)\n      primary_field = name <> \"_id\"\n\n    %{\n      name: name,\n      default_sorting_field: primary_field,\n      fields: [\n        %{name: primary_field, type: \"int32\"},\n        %{name: \"name\", type: \"string\"},\n        %{name: \"country\", type: \"string\"}\n      ]\n    }\n  end\nend\n```\n\nNext, create the collection from a module name.\n\n```elixir\nExTypesense.create_collection(Person)\n```","ref":"readme.html#using-ecto-schema"},{"type":"extras","title":"using map - ExTypesense","doc":"```elixir\nschema = %{\n  name: \"companies\",\n  fields: [\n    %{name: \"company_name\", type: \"string\"},\n    %{name: \"companies_id\", type: \"int32\"},\n    %{name: \"country\", type: \"string\"}\n  ],\n  default_sorting_field: \"companies_id\"\n}\n\nExTypesense.create_collection(schema)\n```\n\n<!-- tabs-close -->","ref":"readme.html#using-map-1"},{"type":"extras","title":"3. Indexing documents - ExTypesense","doc":"<!-- tabs-open -->","ref":"readme.html#3-indexing-documents"},{"type":"extras","title":"single (Ecto) - ExTypesense","doc":"```elixir\nPost |> Repo.get!(123) |> ExTypesense.index_document()\n```","ref":"readme.html#single-ecto"},{"type":"extras","title":"multiple (Ecto) - ExTypesense","doc":"```elixir\nPost |> Repo.all() |> ExTypesense.import_documents()\n```","ref":"readme.html#multiple-ecto"},{"type":"extras","title":"single (map) - ExTypesense","doc":"```elixir\ndocument = %{\n  collection_name: \"companies\",\n  company_name: \"Test\",\n  doc_companies_id: 103,\n  country: \"AL\"\n}\n\nExTypesense.index_document(document)\n\n# or explicitly pass the collection name\ndocument = %{\n  company_name: \"Test\",\n  doc_companies_id: 103,\n  country: \"AL\"\n}\n\nExTypesense.index_document(\"companies\", document)\n```","ref":"readme.html#single-map"},{"type":"extras","title":"multiple (list of maps) - ExTypesense","doc":"```elixir\nmultiple_documents = [\n  %{\n    company_name: \"Boca Cola\",\n    doc_companies_id: 827,\n    country: \"SG\"\n  },\n  %{\n    company_name: \"Motor, Inc.\",\n    doc_companies_id: 549,\n    country: \"TW\"\n  }\n]\n\nExTypesense.import_documents(\"companies\", multiple_documents)\n```\n\n<!-- tabs-close -->","ref":"readme.html#multiple-list-of-maps"},{"type":"extras","title":"4. Search - ExTypesense","doc":"```elixir\nparams = %{q: \"John Doe\", query_by: \"name\"}\n\n# using string collection name\nExTypesense.search(schema.name, params)\n\n# or module name\nExTypesense.search(Person, params)\n```\n\nCheck [Cheatsheet](https://hexdocs.pm/ex_typesense/cheatsheet.html) for more usage examples.","ref":"readme.html#4-search"},{"type":"extras","title":"Miscellaneous - ExTypesense","doc":"","ref":"readme.html#miscellaneous"},{"type":"extras","title":"Adding cache, retry, compress_body in the built in client - ExTypesense","doc":"E.g. when a user wants to change `retry` and `cache` options\n\n```elixir\nExTypesense.get_collection(\"companies\", req: [retry: false, cache: true])\n```\n\nSee implementation: https://github.com/jaeyson/open_api_typesense/blob/main/lib/open_api_typesense/client.ex#L82","ref":"readme.html#adding-cache-retry-compress_body-in-the-built-in-client"},{"type":"extras","title":"Use non-default Finch adapter - ExTypesense","doc":"For instance, in a scenario where an application has multiple Finch pools configured for\ndifferent services, a developer might want to specify a particular Finch pool for the\n`HttpClient` to use. This can be achieved by configuring the options as follows:\n\n```elixir\nconfig :open_api_typesense,\n  api_key: \"XXXXXX\",\n  #...\n  options: [finch: MyApp.CustomFinch] # <- add options\n```\n\nIn this example, `MyApp.CustomFinch` is a custom Finch pool that the developer has\nconfigured with specific connection options or other settings that differ from the\ndefault Finch pool.","ref":"readme.html#use-non-default-finch-adapter"},{"type":"extras","title":"Using another client - ExTypesense","doc":"By default this library is using [Req](https://hexdocs.pm/req/readme.html). In order to use another HTTP client,\nOpenApiTypesense has a callback function ([Behaviours](https://hexdocs.pm/elixir/typespecs.html#behaviours))\ncalled `request` that contains 2 args:\n\n1. `conn`: your connection map\n2. `params`: payload, header, and client-related stuffs.\n\n> #### `conn` and `params` {: .info}\n>\n> you can change the name `conn` and/or `params` however you want,\n> since it's just a variable.\n\nHere's a custom client example ([HTTPoison](https://hexdocs.pm/httpoison/readme.html)) in order to match the usage:\n\n<!-- tabs-open -->","ref":"readme.html#using-another-client"},{"type":"extras","title":"Client module - ExTypesense","doc":"```elixir\ndefmodule MyApp.CustomClient do\n  @behaviour OpenApiTypesense.Client\n  \n  @impl OpenApiTypesense.Client\n  def request(conn, params) do\n    url = %URI{\n      scheme: conn.scheme,\n      host: conn.host,\n      port: conn.port,\n      path: params.url,\n      query: URI.encode_query(params[:query] || %{})\n    }\n    |> URI.to_string()\n\n    request = %HTTPoison.Request{method: params.method, url: url}\n\n    request =\n      if params[:request] do\n        [{content_type, _schema}] = params.request\n\n        headers = [\n          {\"X-TYPESENSE-API-KEY\", conn.api_key}\n          {\"Content-Type\", content_type}\n        ]\n\n        %{request | headers: headers}\n      else\n        request\n      end\n\n    request =\n      if params[:body] do\n        %{request | body: Jason.encode!(params.body)}\n      else\n        request\n      end\n\n    HTTPoison.request!(request)\n  end\nend\n```","ref":"readme.html#client-module"},{"type":"extras","title":"Client config - ExTypesense","doc":"```elixir\nconfig :open_api_typesense,\n  api_key: \"xyz\", # Admin API key\n  host: \"localhost\", # Nodes\n  port: 8108,\n  scheme: \"http\",\n  client: MyApp.CustomClient # <- add this\n```\n\n<!-- tabs-close -->\n\nVisit `open_api_typesense` docs for further [examples](https://hexdocs.pm/open_api_typesense/custom_http_client.html)","ref":"readme.html#client-config"},{"type":"extras","title":"License - ExTypesense","doc":"Copyright (c) 2021 Jaeyson Anthony Y.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE","ref":"readme.html#license"},{"type":"extras","title":"Running local Typesense","doc":"# Running local Typesense\n\nThis document guides you through setting up a local Typesense instance for\ndevelopment purposes. Running a local instance allows you to experiment with\nsearch functionalities and integrate them into your development workflow\nseamlessly.","ref":"running_local_typesense.html"},{"type":"extras","title":"Prerequisites - Running local Typesense","doc":"","ref":"running_local_typesense.html#prerequisites"},{"type":"extras","title":"Install Elixir - Running local Typesense","doc":"This project uses **Elixir version** `>= v1.14`\n\nThere are 4 ways to install Elixir:\n\n<!-- tabs-open -->","ref":"running_local_typesense.html#install-elixir"},{"type":"extras","title":"1. Official Elixir-Lang page - Running local Typesense","doc":"visit https://elixir-lang.org/install.html","ref":"running_local_typesense.html#1-official-elixir-lang-page"},{"type":"extras","title":"2. via vfox - Running local Typesense","doc":"[`vfox`](https://vfox.lhan.me)\n\n1. https://vfox.lhan.me/guides/quick-start.html\n2. https://github.com/version-fox/vfox-elixir\n3. https://github.com/version-fox/vfox-erlang\n4. `vfox use -g erlang@VERSION && vfox use -g elixir@VERSION`","ref":"running_local_typesense.html#2-via-vfox"},{"type":"extras","title":"3. via asdf - Running local Typesense","doc":"[`asdf`](https://asdf-vm.com)\n\n1. https://asdf-vm.com/guide/getting-started.html\n2. https://github.com/asdf-vm/asdf-elixir\n3. https://github.com/asdf-vm/asdf-erlang?tab=readme-ov-file#before-asdf-install\n4. `asdf global elixir VERSION && asdf global erlang VERSION`","ref":"running_local_typesense.html#3-via-asdf"},{"type":"extras","title":"4. using Dockerfile - Running local Typesense","doc":"Please refer to this repo: https://github.com/jaeyson/docker-dev-setup/tree/master/elixir.\n\n> #### editing `elixir.dockerfile` {: .info}\n>\n> you might need to omit packages like `postgres-client`\n> in the `elixir.dockerfile`, since we won't use such package. Also remove\n> the line that contains `RUN mix archive.install hex phx_new --force` since\n> we won't install Phoenix framework.\n\n<!-- tabs-close -->","ref":"running_local_typesense.html#4-using-dockerfile"},{"type":"extras","title":"Install Docker - Running local Typesense","doc":"We use docker container for spinning up local Typesense instance.\n\nHere are 3 ways to install:\n\n<!-- tabs-open -->","ref":"running_local_typesense.html#install-docker"},{"type":"extras","title":"one-line install script (Linux) - Running local Typesense","doc":"> #### not for production use {: .info}\n>\n> This script is intended as a convenient way to configure docker's package\n> repositories and to install Docker Engine, This script is not recommended\n> for production environments.\n\n\n```bash\n# this is slightly edited so that you don't\n# have to save the file on the machine\ncurl -sSL https://get.docker.com/ | sh\n```","ref":"running_local_typesense.html#one-line-install-script-linux"},{"type":"extras","title":"Docker Desktop - Running local Typesense","doc":"- Mac: https://docs.docker.com/desktop/setup/install/mac-install\n- Windows: https://docs.docker.com/desktop/setup/install/windows-install\n- Linux: https://docs.docker.com/desktop/setup/install/linux","ref":"running_local_typesense.html#docker-desktop"},{"type":"extras","title":"Orbstack - Running local Typesense","doc":"https://orbstack.dev\n\n<!-- tabs-close -->","ref":"running_local_typesense.html#orbstack"},{"type":"extras","title":"Setting up - Running local Typesense","doc":"We are using Docker compose to bootstrap a local Typesense instance from a\nsample docker compose file.\n\nClone the `ex_typesense` GitHub repository:\n\n```bash\ngit clone https://github.com/jaeyson/ex_typesense.git\n```\n\nNavigate to the cloned GitHub repository and start the Typesense instance:\n\n```bash\ncd ex_typesense\n\ndocker compose up -d\n```\n\nMore info on spinning a local instance: https://typesense.org/docs/guide/install-typesense.html\n\nOnce you've started Typesense, you can verify its installation by accessing the\nhealth endpoint through a browser or `curl` in the terminal:\n\n```bash\n$ curl http://localhost:8108/health\n{\"ok\":true}\n```\n\nIn a separate terminal, you can view the logs of your local Typesense instance\nusing following command:\n\n```bash\n# logs from all instances\ndocker compose logs -f\n\n# or specifically Typesense\ndocker container logs --follow --tail 50 typesense\n```\n\nThis Docker Compose setup exposes three services with dedicated URLs:\n\n- http://localhost:8107 (Internal Server Status), provides information about the\n  health and status of your internal server.\n- http://localhost:8108 (Typesense Server and API), allows you to interact with\n  the Typesense search engine and its API functionalities.\n- http://localhost:8109 (Typesense Dashboard), opens the Typesense web interface\n  for managing your search collections and settings.","ref":"running_local_typesense.html#setting-up"},{"type":"extras","title":"Cheatsheet","doc":"# Cheatsheet Example","ref":"cheatsheet.html"},{"type":"extras","title":"Collections - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#collections"},{"type":"extras","title":"1. Create using schema - Cheatsheet","doc":"```elixir\ndefmodule MyApp.Listings.Company do\n  use Ecto.Schema\n  @behaviour ExTypesense\n\n  defimpl Jason.Encoder, for: __MODULE__ do\n    def encode(value, opts) do\n      value\n      |> Map.take([:companies_id, :name, :country])\n      |> Enum.map(fn {key, val} ->\n        if key === :companies_id, do: {key, Map.get(value, :id)}, else: {key, val}\n      end)\n      |> Enum.into(%{})\n      |> Jason.Encode.map(opts)\n    end\n  end\n\n  schema \"companies\" do\n    field(:name, :string)\n    field(:country, :string)\n    field(:companies_id, :integer, virtual: true)\n  end\n\n  @impl ExTypesense\n  def get_field_types do\n    name = __MODULE__.__schema__(:source)\n    primary_field = name <> \"_id\"\n\n    %{\n      name: name,\n      default_sorting_field: primary_field,\n      fields: [\n        %{name: primary_field, type: \"int32\"},\n        %{name: \"name\", type: \"string\"},\n        %{name: \"country\", type: \"string\"}\n      ]\n    }\n  end\nend\n```","ref":"cheatsheet.html#1-create-using-schema"},{"type":"extras","title":"2. Create the collection in iex -S mix shell - Cheatsheet","doc":"```elixir\niex> ExTypesense.create_collection(Company)\n{:ok,\n  %OpenApiTypesense.CollectionResponse{\n    created_at: 1234567890,\n    default_sorting_field: \"companies_id\",\n    fields: [...],\n    name: \"companies\",\n    num_documents: 0,\n    symbols_to_index: [],\n    token_separators: []\n  }\n}\n```","ref":"cheatsheet.html#2-create-the-collection-in-iex-s-mix-shell"},{"type":"extras","title":"Create using map - Cheatsheet","doc":"```elixir\niex> schema =\n...> %{\n...>   name: \"companies\",\n...>   fields: [\n...>     %{name: \"company_name\", type: \"string\"},\n...>     %{name: \"companies_id\", type: \"int32\"},\n...>     %{name: \"country\", type: \"string\", facet: true}\n...>   ],\n...>   default_sorting_field: \"companies_id\"\n...> }\n\niex> ExTypesense.create_collection(schema)\n{:ok,\n  %OpenApiTypesense.CollectionResponse{\n    created_at: 1234567890,\n    default_sorting_field: \"companies_id\",\n    fields: [...],\n    name: \"companies\",\n    num_documents: 0,\n    symbols_to_index: [],\n    token_separators: []\n  }\n}\n```\n\n## \n\n{: .col-2}","ref":"cheatsheet.html#create-using-map"},{"type":"extras","title":"List collections - Cheatsheet","doc":"```elixir\niex> ExTypesense.list_collections()\n{:ok, []}\n```","ref":"cheatsheet.html#list-collections"},{"type":"extras","title":"Clone collections - Cheatsheet","doc":"```elixir\niex> ExTypesense.clone_collection(\"companies\", \"new_companies\")\n{:ok,\n  %OpenApiTypesense.CollectionResponse{\n    created_at: 1234567890,\n    default_sorting_field: \"companies_id\",\n    fields: [...],\n    name: \"new_companies\",\n    num_documents: 0,\n    symbols_to_index: [],\n    token_separators: []\n  }\n}\n```","ref":"cheatsheet.html#clone-collections"},{"type":"extras","title":"Get collection - Cheatsheet","doc":"```elixir\niex> ExTypesense.get_collection(MyApp.Context.Company)\n{\n  :ok,\n  %OpenApiTypesense.CollectionResponse{\n    name: \"companies\",\n    fields: [...],\n    default_sorting_field: \"company_id\",\n    created_at: 1737896943,\n    enable_nested_fields: false,\n    num_documents: 0,\n    symbols_to_index: [],\n    token_separators: [],\n    voice_query_model: nil\n  }\n}\n```","ref":"cheatsheet.html#get-collection"},{"type":"extras","title":"Update a collection - Cheatsheet","doc":"```elixir\niex> schema =\n...> %{\n...>   fields: [\n...>     %{name: \"country\", drop: true},\n...>     %{name: \"company_category\", type: \"string\"},\n...>   ],\n...> }\n\niex> ExTypesense.update_collection_fields(\"companies\", schema)\n{:ok,\n  %OpenApiTypesense.CollectionUpdateSchema{\n    \"fields\" => [\n      %{name: \"country\", drop: true},\n      %{name: \"company_category\", type: \"string\"}\n    ]\n  }\n}\n```","ref":"cheatsheet.html#update-a-collection"},{"type":"extras","title":"Drop a collection - Cheatsheet","doc":"```elixir\niex> ExTypesense.drop_collection(MyApp.Context.Company)\n\niex> ExTypesense.drop_collection(\"companies\")\n{\n  :ok,\n  %OpenApiTypesense.CollectionResponse{\n    name: \"companies\",\n    fields: [...],\n    default_sorting_field: \"company_id\",\n    created_at: 1737895283,\n    enable_nested_fields: false,\n    num_documents: 0,\n    symbols_to_index: [],\n    token_separators: [],\n    voice_query_model: nil\n  }\n}\n```","ref":"cheatsheet.html#drop-a-collection"},{"type":"extras","title":"Documents - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#documents"},{"type":"extras","title":"Indexes multiple documents with Ecto structs - Cheatsheet","doc":"```elixir\niex> posts = Post |> Repo.all()\niex> ExTypesense.import_documents(Post, posts)\n\n{:ok, [%{\"success\" => true}, %{\"success\" => true}]}\n```","ref":"cheatsheet.html#indexes-multiple-documents-with-ecto-structs"},{"type":"extras","title":"Delete a document by query - Cheatsheet","doc":"```elixir\niex> opts = [\n...>   filter_by: \"num_employees:>100\",\n...>   batch_size: 100\n...> ]\n\niex> ExTypesense.delete_documents_by_query(Employee, opts)\n{:ok, %OpenApiTypesense.Documents{num_deleted: 1}}\n```","ref":"cheatsheet.html#delete-a-document-by-query"},{"type":"extras","title":"Index a document using map - Cheatsheet","doc":"```elixir\niex> document = %{\n...>   collection_name: \"companies\",\n...>   company_name: \"Malwart\",\n...>   companies_id: 1001,\n...>   country: \"US\"\n...> }\niex> ExTypesense.index_document(document)\n{:ok,\n  %{\n    id: \"0\",\n    ...\n  }\n}\n```","ref":"cheatsheet.html#index-a-document-using-map"},{"type":"extras","title":"Index a document from an Ecto schema - Cheatsheet","doc":"```elixir\niex> post = Post |> limit(1) |> Repo.one()\niex> ExTypesense.index_document(post, :create)\n{:ok,\n  %{\n    id: \"12\",\n    ...\n  }\n}\n```","ref":"cheatsheet.html#index-a-document-from-an-ecto-schema"},{"type":"extras","title":"Indexes multiple documents with maps - Cheatsheet","doc":"```elixir\niex> documents = [\n...>   %{\n...>     company_name: \"Industrial Mills, Co.\",\n...>     doc_companies_id: 990,\n...>     country: \"US\"\n...>   },\n...>   %{\n...>     company_name: \"Washing Machine, Inc.\",\n...>     doc_companies_id: 10,\n...>     country: \"US\"\n...>   }\n...> ]\n\niex> ExTypesense.import_documents(\"companies\", documents)\n{:ok, [%{\"success\" => true}, %{\"success\" => true}]}\n```","ref":"cheatsheet.html#indexes-multiple-documents-with-maps"},{"type":"extras","title":"update using Ecto struct - Cheatsheet","doc":"```elixir\niex> post = Post |> limit(1) |> Repo.one()\n\niex> ExTypesense.update_document(post, 0)\n{:ok,\n  %OpenApiTypesense.Documents{\n    num_deleted: nil,\n    num_updated: 1\n  }\n}\n```","ref":"cheatsheet.html#update-using-ecto-struct"},{"type":"extras","title":"Delete a document - Cheatsheet","doc":"```elixir\niex> ExTypesense.delete_document(Post, 0)\n\n{:ok,\n  %{\n    id: \"0\",\n    collection_name: \"posts\",\n    posts_id: 34,\n    title: \"test\",\n    description: \"lorem ipsum\"\n  }\n}\n```","ref":"cheatsheet.html#delete-a-document"},{"type":"extras","title":"How to use search - Cheatsheet","doc":"{: .col-2}","ref":"cheatsheet.html#how-to-use-search"},{"type":"extras","title":"Search using module name (atom) - Cheatsheet","doc":"```elixir\niex> params = %{q: \"test\", query_by: \"title\"}\niex> ExTypesense.search(Post, params)\n{:ok,\n  %OpenApiTypesense.SearchResult{\n    found: 0,\n    conversation: nil,\n    facet_counts: [],\n    found_docs: nil,\n    grouped_hits: nil,\n    hits: [...]\n    out_of: 0,\n    page: 1,\n    request_params: %{q: \"test\", collection_name: \"posts\", first_q: \"test\", per_page: 10},\n    search_cutoff: false,\n    search_time_ms: 5\n  }\n}\n```","ref":"cheatsheet.html#search-using-module-name-atom"},{"type":"extras","title":"Search returns Ecto query - Cheatsheet","doc":"```elixir\niex> params = %{q: \"test\", query_by: \"title\"}\niex> ExTypesense.search_ecto(Post, params)\n{:ok,\n  %OpenApiTypesense.SearchResult{\n    found: 0,\n    conversation: nil,\n    facet_counts: [],\n    found_docs: nil,\n    grouped_hits: nil,\n    hits: [...]\n    out_of: 0,\n    page: 1,\n    request_params: %{q: \"test\", collection_name: \"posts\", first_q: \"test\", per_page: 10},\n    search_cutoff: false,\n    search_time_ms: 5\n  }\n}\n```","ref":"cheatsheet.html#search-returns-ecto-query"},{"type":"extras","title":"Multi search - Cheatsheet","doc":"```elixir\niex> searches = [\n...>   %{collection: \"companies\", q: \"Loca Cola\"},\n...>   %{collection: Company, q: \"Burgler King\"},\n...>   %{collection: Catalog, q: \"umbrella\"}\n...> ]\niex> ExTypesense.multi_search(searches)\n{:ok,\n  [\n    {\n      %{\"facet_counts\" => [], \"found\" => 0, \"hits\" => [], ...},\n      %{\"facet_counts\" => [], \"found\" => 0, \"hits\" => [], ...},\n      %{\"facet_counts\" => [], \"found\" => 0, \"hits\" => [], ...},\n    }\n  ]\n}\n```","ref":"cheatsheet.html#multi-search"},{"type":"extras","title":"Search using collection name (string) - Cheatsheet","doc":"```elixir\niex> params = %{q: \"test\", query_by: \"title\"}\niex> ExTypesense.search(\"posts\", params)\n{:ok,\n  %OpenApiTypesense.SearchResult{\n    found: 2,\n    conversation: nil,\n    facet_counts: [],\n    found_docs: nil,\n    grouped_hits: nil,\n    hits: [...]\n    out_of: 4,\n    page: 1,\n    request_params: %{q: \"test\", collection_name: \"posts\", first_q: \"test\", per_page: 10},\n    search_cutoff: false,\n    search_time_ms: 5\n  }\n}\n```","ref":"cheatsheet.html#search-using-collection-name-string"},{"type":"extras","title":"License","doc":"# MIT License\n\nCopyright (c) 2021 Jaeyson Anthony Y.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE","ref":"license.html"},{"type":"extras","title":"Contributing","doc":"# Contributing","ref":"contributing.html"},{"type":"extras","title":"Pull Request - Contributing","doc":"1. Fork repo (https://github.com/jaeyson/ex_typesense/fork)\n2. Clone to your local machine, `git clone git@github.com:your_username/ex_typesense.git && cd ex_typesense`\n3. Create branch, _e.g._ `git checkout -b manage-backups-and-restores`\n4. Commit changes, _e.g._ `git commit -am 'manage backups and restores (snapshots)'`\n5. Push the new branch, _e.g._ `git push -u origin manage-backups-and-restores`\n6. [Create new Pull Request](https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/proposing-changes-to-your-work-with-pull-requests/creating-a-pull-request)","ref":"contributing.html#pull-request"},{"type":"extras","title":"Local development - Contributing","doc":"Please refer: https://hexdocs.pm/ex_typesense/running_local_typesense.html","ref":"contributing.html#local-development"},{"type":"extras","title":"Code of Conduct","doc":"# Contributor Covenant Code of Conduct","ref":"code_of_conduct.html"},{"type":"extras","title":"Our Pledge - Code of Conduct","doc":"We as the maintainers of this project, respects all people who contributes via raising issues, submission of requests, enhancement of documentation, patches and rest of activities regardless of the level of experience. We aim an inclusive, diverse, welcoming, open, and healthy interaction towards the community.","ref":"code_of_conduct.html#our-pledge"},{"type":"extras","title":"Our Standards - Code of Conduct","doc":"Examples of behavior that contributes to a positive environment for our\ncommunity include:\n\n* Demonstrating empathy and kindness toward other people\n* Being respectful of differing opinions, viewpoints, and experiences\n* Giving and gracefully accepting constructive feedback\n* Accepting responsibility and apologizing to those affected by our mistakes,\n  and learning from the experience\n* Focusing on what is best not just for us as individuals, but for the overall\n  community\n\nExamples of unacceptable behavior include:\n\n* The use of sexualized language or imagery, and sexual attention or advances of\n  any kind\n* Trolling, insulting or derogatory comments, and personal or political attacks\n* Public or private harassment\n* Publishing others' private information, such as a physical or email address,\n  without their explicit permission\n* Other conduct which could reasonably be considered inappropriate in a\n  professional setting","ref":"code_of_conduct.html#our-standards"},{"type":"extras","title":"Enforcement Responsibilities - Code of Conduct","doc":"Maintainers have the right and responsibility to remove, edit, or reject\ncomments, commits, code, wiki edits, issues, and other contributions that are\nnot aligned to this Code of Conduct, and will communicate reasons for moderation\ndecisions when appropriate.","ref":"code_of_conduct.html#enforcement-responsibilities"},{"type":"extras","title":"Scope - Code of Conduct","doc":"This Code of Conduct applies within all this project, and also applies when\nan individual is officially representing the community in public spaces.","ref":"code_of_conduct.html#scope"},{"type":"extras","title":"Enforcement - Code of Conduct","doc":"Instances of abusive, harassing, or otherwise unacceptable behavior may be\nreported by opening an issue or contacting one or more of the project maintainers.\nAll complaints will be reviewed and investigated promptly and fairly.\n\nAll community leaders are obligated to respect the privacy and security of the\nreporter of any incident.","ref":"code_of_conduct.html#enforcement"},{"type":"extras","title":"Attribution - Code of Conduct","doc":"This Code of Conduct is adapted from the [Contributor Covenant][homepage],\nversion 2.1, available at\n[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1].\n\n[homepage]: https://www.contributor-covenant.org\n[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html","ref":"code_of_conduct.html#attribution"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}